% Auto-generated chapter 34 for abudawud
% Hadiths in this chapter: 139

\hadithdefcmd{abudawud}{4020}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَجَدَّ ثَوْبًا سَمَّاهُ بِاسْمِهِ إِمَّا قَمِيصًا أَوْ عِمَامَةً ثُمَّ يَقُولُ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ كَسَوْتَنِيهِ أَسْأَلُكَ مِنْ خَيْرِهِ وَخَيْرِ مَا صُنِعَ لَهُ وَأَعُوذُ بِكَ مِنْ شَرِّهِ وَشَرِّ مَا صُنِعَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو نَضْرَةَ فَكَانَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم إِذَا لَبِسَ أَحَدُهُمْ ثَوْبًا جَدِيدًا قِيلَ لَهُ تُبْلِي وَيُخْلِفُ اللَّهُ تَعَالَى ‏.‏\hadithno{4020}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: When the Messenger of Allah (ﷺ) put on a new garment he mentioned it by name, turban or shirt, and would then say: O Allah, praise be to Thee! as Thou hast clothed me with it, I ask Thee for its good and the good of that for which it was made, and I seek refuge in Thee from its evil and the evil of that for which it was made. Abu Nadrah said: When any of the Companions of the Prophet (ﷺ) put on a new garment, he was told: May you wear it out and may Allah give you another in its place}}
\hadithdefcmd{abudawud}{4021}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الْجُرَيْرِيِّ، بِإِسْنَادِهِ نَحْوَهُ ‏.‏\hadithno{4021}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Al-Jariri through a different chain of narrators in a similar way}}
\hadithdefcmd{abudawud}{4022}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ دِينَارٍ، عَنِ الْجُرَيْرِيِّ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ عَبْدُ الْوَهَّابِ الثَّقَفِيُّ لَمْ يَذْكُرْ فِيهِ أَبَا سَعِيدٍ وَحَمَّادُ بْنُ سَلَمَةَ قَالَ عَنِ الْجُرَيْرِيِّ عَنْ أَبِي الْعَلاَءِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ حَمَّادُ بْنُ سَلَمَةَ وَالثَّقَفِيُّ سَمَاعُهُمَا وَاحِدٌ ‏.‏\hadithno{4022}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by al-Jariri to the same effect though a different chain of narrators. Abu Dawud said:'Abd al-Wahhab al-Thaqafi did not mention the name of Abu Sa'id. Hammad b. Salamah said: From al-Jariri, from Abu al-'Ala', from the Prophet (ﷺ). Abu Dawud said: The hearing of this tradition by Hammad b. Salamah and Thaqafi is of the same nature}}
\hadithdefcmd{abudawud}{4023}{حَدَّثَنَا نُصَيْرُ بْنُ الْفَرَجِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدٌ، - يَعْنِي ابْنَ أَبِي أَيُّوبَ - عَنْ أَبِي مَرْحُومٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ طَعَامًا ثُمَّ قَالَ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنِي هَذَا الطَّعَامَ وَرَزَقَنِيهِ مِنْ غَيْرِ حَوْلٍ مِنِّي وَلاَ قُوَّةٍ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ وَمَنْ لَبِسَ ثَوْبًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي كَسَانِي هَذَا الثَّوْبَ وَرَزَقَنِيهِ مِنْ غَيْرِ حَوْلٍ مِنِّي وَلاَ قُوَّةٍ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ ‏"‏ ‏.‏\hadithno{4023}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mu'adh ibn Anas: The Prophet (ﷺ) said: If anyone eats food and then says: "Praise be to Allah Who has fed me with this food and provided me with it through no might and power on my part," he will be forgiven his former and later sins. If anyone puts on a garment and says: "Praise be to Allah Who has clothed me with this and provided me with it through no might and power on my part," he will be forgiven his former and later sins}}
\hadithdefcmd{abudawud}{4024}{حَدَّثَنَا إِسْحَاقُ بْنُ الْجَرَّاحِ الأَذَنِيُّ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أُمِّ خَالِدٍ بِنْتِ خَالِدِ بْنِ سَعِيدِ بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِكِسْوَةٍ فِيهَا خَمِيصَةٌ صَغِيرَةٌ فَقَالَ ‏"‏ مَنْ تَرَوْنَ أَحَقَّ بِهَذِهِ ‏"‏ ‏.‏ فَسَكَتَ الْقَوْمُ فَقَالَ ‏"‏ ائْتُونِي بِأُمِّ خَالِدٍ ‏"‏ ‏.‏ فَأُتِيَ بِهَا فَأَلْبَسَهَا إِيَّاهَا ثُمَّ قَالَ ‏"‏ أَبْلِي وَأَخْلِقِي ‏"‏ ‏.‏ مَرَّتَيْنِ وَجَعَلَ يَنْظُرُ إِلَى عَلَمٍ فِي الْخَمِيصَةِ أَحْمَرَ أَوْ أَصْفَرَ وَيَقُولُ ‏"‏ سَنَاهْ سَنَاهْ يَا أُمَّ خَالِدٍ ‏"‏ ‏.‏ وَسَنَاهْ فِي كَلاَمِ الْحَبَشَةِ الْحَسَنُ ‏.‏\hadithno{4024}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5823)}\hadithtrans{Narrated Umm Khalid, daughter of Sa'd b. al-'As:Once the Messenger of Allah (ﷺ) was brought some garments among which was a small cloak with a border and black stripes. He said: Whom do you think to be more deserving for it ? The people kept silence. He said: Bring Umm Khalid. The she was carried to him and he put it on her, saying: Wear it out and make it ragged twice. Then he went on looking at red or yellow marks on it, and said: This is sanah, sanah, Umm Khalid. It means "beautiful" in the language of the Abyssinians}}
\hadithdefcmd{abudawud}{4025}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ الْحَنَفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ أَحَبَّ الثِّيَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْقَمِيصُ ‏.‏\hadithno{4025}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The clothing which the Messenger of Allah (ﷺ) liked best was shirt}}
\hadithdefcmd{abudawud}{4026}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا أَبُو تُمَيْلَةَ، قَالَ حَدَّثَنِي عَبْدُ الْمُؤْمِنِ بْنُ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ لَمْ يَكُنْ ثَوْبٌ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ قَمِيصٍ ‏.‏\hadithno{4026}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: No clothing was dearer to be Messenger of Allah (ﷺ) than shirt}}
\hadithdefcmd{abudawud}{4027}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، عَنْ أَبِيهِ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، قَالَتْ كَانَتْ يَدُ كُمِّ قَمِيصِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الرُّصْغِ ‏.‏\hadithno{4027}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Asma', daughter of Yazid,: The sleeve of the shirt of the Messenger of Allah (ﷺ) came to the wrist}}
\hadithdefcmd{abudawud}{4028}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ، - الْمَعْنَى - أَنَّ اللَّيْثَ، - يَعْنِي ابْنَ سَعْدٍ - حَدَّثَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّهُ قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْبِيَةً وَلَمْ يُعْطِ مَخْرَمَةَ شَيْئًا فَقَالَ مَخْرَمَةُ يَا بُنَىَّ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَانْطَلَقْتُ مَعَهُ قَالَ ادْخُلْ فَادْعُهُ لِي قَالَ فَدَعَوْتُهُ فَخَرَجَ إِلَيْهِ وَعَلَيْهِ قِبَاءٌ مِنْهَا فَقَالَ ‏ "‏ خَبَأْتُ هَذَا لَكَ ‏"‏ ‏.‏ قَالَ فَنَظَرَ إِلَيْهِ - زَادَ ابْنُ مَوْهَبٍ - مَخْرَمَةُ - ثُمَّ اتَّفَقَا - قَالَ رَضِيَ مَخْرَمَةُ ‏.‏ قَالَ قُتَيْبَةُ عَنِ ابْنِ أَبِي مُلَيْكَةَ لَمْ يُسَمِّهِ ‏.‏\hadithno{4028}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2599) Sahih Muslim (1058)}\hadithtrans{Narrated Al-Miswar b. Makhramah:The Messenger of Allah (ﷺ) distributed outer garments with full-length sleeves but did not give Makhramah anything. Makhramah said: Go with us to the Messenger of Allah (ﷺ). So I went with him and he said: Enter and call him for me. I then called him. He came out to him and he had an outer garment with full-length sleeves over him from those garments. He said: I kept it for you. He looked at it, meaning Makhramah according to the addition of Ibn Mawhab. The agreed version then says: He said: Makhramah was pleased. Ibn Qutaibah said: From Ibn Abi Mulaikah, but he did not name it}}
\hadithdefcmd{abudawud}{4029}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ عِيسَى - عَنْ شَرِيكٍ، عَنْ عُثْمَانَ بْنِ أَبِي زُرْعَةَ، عَنِ الْمُهَاجِرِ الشَّامِيِّ، عَنِ ابْنِ عُمَرَ، - قَالَ فِي حَدِيثِ شَرِيكٍ يَرْفَعُهُ - قَالَ ‏"‏ مَنْ لَبِسَ ثَوْبَ شُهْرَةٍ أَلْبَسَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ثَوْبًا مِثْلَهُ ‏"‏ ‏.‏ زَادَ عَنْ أَبِي عَوَانَةَ ‏"‏ ثُمَّ تُلَهَّبُ فِيهِ النَّارُ ‏"‏ ‏.‏\hadithno{4029}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) as saying: If anyone wears a garment for gaining fame, Allah will clothe him in a similar garment on the Day of Resurrection}}
\hadithdefcmd{abudawud}{4030}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، قَالَ ثَوْبَ مَذَلَّةٍ ‏.‏\hadithno{4030}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Musaddad transmitted the tradition mentioned above from Abu 'Awanah saying:Garment of disgrace}}
\hadithdefcmd{abudawud}{4031}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَابِتٍ، حَدَّثَنَا حَسَّانُ بْنُ عَطِيَّةَ، عَنْ أَبِي مُنِيبٍ الْجُرَشِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَشَبَّهَ بِقَوْمٍ فَهُوَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{4031}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: He who copies any people is one of them}}
\hadithdefcmd{abudawud}{4032}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، وَحُسَيْنُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ مِرْطٌ مُرَحَّلٌ مِنْ شَعْرٍ أَسْوَدَ ‏.‏ وَقَالَ حُسَيْنٌ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا ‏.‏ - حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْعَلاَءِ الزُّبَيْدِيُّ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ عَنْ عَقِيلِ بْنِ مُدْرِكٍ عَنْ لُقْمَانَ بْنِ عَامِرٍ عَنْ عُتْبَةَ بْنِ عَبْدٍ السُّلَمِيِّ قَالَ اسْتَكْسَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَسَانِي خَيْشَتَيْنِ فَلَقَدْ رَأَيْتُنِي وَأَنَا أَكْسَى أَصْحَابِي ‏.‏\hadithno{4032}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah said:The Messenger of Allah (ﷺ) went out one morning wearing a variegated garment of black goat hair. Narrated Utbah ibn AbdusSulami: I asked the Messenger of Allah (ﷺ) to clothe me. He clothed me with two coarse clothes of linen}}
\hadithdefcmd{abudawud}{4033}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي بُرْدَةَ، قَالَ قَالَ لِي أَبِي يَا بُنَىَّ لَوْ رَأَيْتَنَا وَنَحْنُ مَعَ نَبِيِّنَا صلى الله عليه وسلم وَقَدْ أَصَابَتْنَا السَّمَاءُ حَسِبْتَ أَنَّ رِيحَنَا رِيحُ الضَّأْنِ ‏.‏\hadithno{4033}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Burdah: My father said to me: My son, if you had seen us while we were with the Messenger of Allah (ﷺ) and the rain had fallen on us, you would have thought that our smell was the smell of the sheep}}
\hadithdefcmd{abudawud}{4034}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا عُمَارَةُ بْنُ زَاذَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ مَلِكَ، ذِي يَزَنَ أَهْدَى إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةً أَخَذَهَا بِثَلاَثَةٍ وَثَلاَثِينَ بَعِيرًا أَوْ ثَلاَثٍ وَثَلاَثِينَ نَاقَةً فَقَبِلَهَا ‏.‏\hadithno{4034}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The King Dhu Yazan presented to the apostle of Allah (ﷺ) a suit of clothes which he had purchased for thirty-three camels or thirty-three she-camels. He accepted it}}
\hadithdefcmd{abudawud}{4035}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اشْتَرَى حُلَّةً بِبِضْعَةٍ وَعِشْرِينَ قَلُوصًا فَأَهْدَاهَا إِلَى ذِي يَزَنَ ‏.‏\hadithno{4035}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ishaq ibn Abdullah ibn al-Harith: The Messenger of Allah (ﷺ) purchased a suit of clothes for twenty she-camels and some more and he presented it to Dhu Yazan}}
\hadithdefcmd{abudawud}{4036}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُوسَى، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - الْمَعْنَى - عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ - رضى الله عنها - فَأَخْرَجَتْ إِلَيْنَا إِزَارًا غَلِيظًا مِمَّا يُصْنَعُ بِالْيَمَنِ وَكِسَاءً مِنَ الَّتِي يُسَمُّونَهَا الْمُلَبَّدَةَ فَأَقْسَمَتْ بِاللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قُبِضَ فِي هَذَيْنِ الثَّوْبَيْنِ ‏.‏\hadithno{4036}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2080)}\hadithtrans{Narrated Abu Burdah:I entered upon 'Aishah, and she brought a coarse lower garment that was manufactured in the Yemen and a patched garment called mulabbadah. She swore by Allah that the spirit of the Messenger of Allah (ﷺ) was taken in these two clothes}}
\hadithdefcmd{abudawud}{4037}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ أَبُو ثَوْرٍ الْكَلْبِيُّ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ بْنِ الْقَاسِمِ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا أَبُو زُمَيْلٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ، قَالَ لَمَّا خَرَجَتِ الْحَرُورِيَّةُ أَتَيْتُ عَلِيًّا - رضى الله عنه - فَقَالَ ائْتِ هَؤُلاَءِ الْقَوْمَ ‏.‏ فَلَبِسْتُ أَحْسَنَ مَا يَكُونُ مِنْ حُلَلِ الْيَمَنِ - قَالَ أَبُو زُمَيْلٍ وَكَانَ ابْنُ عَبَّاسٍ رَجُلاً جَمِيلاً جَهِيرًا - قَالَ ابْنُ عَبَّاسٍ فَأَتَيْتُهُمْ فَقَالُوا مَرْحَبًا بِكَ يَا ابْنَ عَبَّاسٍ مَا هَذِهِ الْحُلَّةُ قَالَ مَا تَعِيبُونَ عَلَىَّ لَقَدْ رَأَيْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَحْسَنَ مَا يَكُونُ مِنَ الْحُلَلِ ‏.‏ قَالَ أَبُو دَاوُدَ اسْمُ أَبِي زُمَيْلٍ سِمَاكُ بْنُ الْوَلِيدِ الْحَنَفِيُّ ‏.‏\hadithno{4037}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: When the Haruriyyah made a revolt, I came to Ali (may Allah be pleased with him). He said: Go to these people. I then put on the best suit of the Yemen. AbuZumayl (a transmitter) said: Ibn Abbas was handsome and of imposing countenance. Ibn Abbas said: I then came to them and they said: Welcome to you, Ibn Abbas! what is this suit of clothes? I said: Why are you objecting to me? I saw over the Messenger of Allah (ﷺ) the best suit of clothes. Abu Dawud said: The name of Abu Zumail is Sammak b. al-Walid al-Hanafi}}
\hadithdefcmd{abudawud}{4038}{حَدَّثَنَا عُثْمَانُ بْنُ مُحَمَّدٍ الأَنْمَاطِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ الرَّازِيُّ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ الرَّازِيُّ، حَدَّثَنَا أَبِي، أَخْبَرَنِي أَبِي عَبْدُ اللَّهِ بْنُ سَعْدٍ، عَنْ أَبِيهِ، سَعْدٍ قَالَ رَأَيْتُ رَجُلاً بِبُخَارَى عَلَى بَغْلَةٍ بَيْضَاءَ عَلَيْهِ عِمَامَةُ خَزٍّ سَوْدَاءُ فَقَالَ كَسَانِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ هَذَا لَفْظُ عُثْمَانَ وَالإِخْبَارُ فِي حَدِيثِهِ ‏.‏\hadithno{4038}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd: I saw a man riding on a white mule and he had a black turban of silk and wool. He said: The Messenger of Allah (ﷺ) put it on me. This is the version of Uthman, and there is the word akhbara in his tradition}}
\hadithdefcmd{abudawud}{4039}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا بِشْرُ بْنُ بَكْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنَا عَطِيَّةُ بْنُ قَيْسٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ غَنْمٍ الأَشْعَرِيَّ، قَالَ حَدَّثَنِي أَبُو عَامِرٍ، أَوْ أَبُو مَالِكٍ - وَاللَّهِ يَمِينٌ أُخْرَى مَا كَذَبَنِي - أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَيَكُونَنَّ مِنْ أُمَّتِي أَقْوَامٌ يَسْتَحِلُّونَ الْخَزَّ وَالْحَرِيرَ ‏"‏ ‏.‏ وَذَكَرَ كَلاَمًا قَالَ ‏"‏ يُمْسَخُ مِنْهُمْ آخَرُونَ قِرَدَةً وَخَنَازِيرَ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَعِشْرُونَ نَفْسًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ أَكْثَرُ لَبِسُوا الْخَزَّ مِنْهُمْ أَنَسٌ وَالْبَرَاءُ بْنُ عَازِبٍ ‏.‏\hadithno{4039}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (5590)}\hadithtrans{Narrated Abdur Rahman ibn Ghanam al-Ash'ari: Abu Amir or Abu Malik told me--I swear by Allah another oath that he did not believe me that he heard the Messenger of Allah (ﷺ) say: There will be among my community people who will make lawful (the use of) khazz and silk. Some of them will be transformed into apes and swine. Abu Dawud said: Twenty Companions of the Messenger of Allah (ﷺ) or more put on khazz. Anas and al-Bara' b. 'Azib were among them}}
\hadithdefcmd{abudawud}{4040}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَأَى حُلَّةً سِيَرَاءَ عِنْدَ بَابِ الْمَسْجِدِ تُبَاعُ فَقَالَ يَا رَسُولَ اللَّهِ لَوِ اشْتَرَيْتَ هَذِهِ فَلَبِسْتَهَا يَوْمَ الْجُمُعَةِ وَلِلْوَفْدِ إِذَا قَدِمُوا عَلَيْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏ ثُمَّ جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْهَا حُلَلٌ فَأَعْطَى عُمَرَ بْنَ الْخَطَّابِ مِنْهَا حُلَّةً فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ كَسَوْتَنِيهَا وَقَدْ قُلْتَ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَمْ أَكْسُكَهَا لِتَلْبَسَهَا ‏"‏ ‏.‏ فَكَسَاهَا عُمَرُ بْنُ الْخَطَّابِ أَخًا لَهُ مُشْرِكًا بِمَكَّةَ ‏.‏\hadithno{4040}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2612) Sahih Muslim (2068)}\hadithtrans{Narrated 'Abd Allaah b. 'Umar:'Umar b. al-Khattab saw that a striped robe containing silk was being sold at the the gate of the mosque. He said: Messenger of Allah, would that you purchased it and wore it on Friday and when a delegation came to you. The Messenger of Allah (ﷺ) said: Only he who has no portion in the next world wears this (silk). Then the Messenger of Allah (ﷺ) came in possession of some robes made of silk and gave one of them to 'Umar b. al-Khattab. 'Umar said: Messenger of Allah, you are clothing me with it, but you said about the robe of 'Utarid what you said. The Messenger of Allah (ﷺ) said: I did not give it to you so that you may wear it. So 'Umar al-Khattab gave it to his brother who was a polytheist in Mecca to wear it}}
\hadithdefcmd{abudawud}{4041}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، وَعَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، بِهَذِهِ الْقِصَّةِ قَالَ حُلَّةَ إِسْتَبْرَقٍ ‏.‏ وَقَالَ فِيهِ ثُمَّ أَرْسَلَ إِلَيْهِ بِجُبَّةِ دِيبَاجٍ وَقَالَ ‏ "‏ تَبِيعُهَا وَتُصِيبُ بِهَا حَاجَتَكَ ‏"‏ ‏.‏\hadithno{4041}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2054) Sahih Muslim (2068)}\hadithtrans{The tradition mentioned above has also been narrated by 'Abd Allah b. 'Umar through a different chain of narrators. This version has:He said: A robe of silk brocade. He then sent him a Jubbah of brocade and said: You may sell it and fulfill your need}}
\hadithdefcmd{abudawud}{4042}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، قَالَ كَتَبَ عُمَرُ إِلَى عُتْبَةَ بْنِ فَرْقَدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْحَرِيرِ إِلاَّ مَا كَانَ هَكَذَا وَهَكَذَا أُصْبُعَيْنِ وَثَلاَثَةً وَأَرْبَعَةً ‏.‏\hadithno{4042}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5829) Sahih Muslim (2069)}\hadithtrans{Narrated Abu 'Uthman al-Nahdi:'Umar wrote to 'Utbah b. Farqad that the Prophet (ﷺ) forbade (wearing) silk except so-and-so, and so-and-so, to the extent of two, three, or four fingers}}
\hadithdefcmd{abudawud}{4043}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، يُحَدِّثُ عَنْ عَلِيٍّ، رضى الله عنه قَالَ أُهْدِيَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةٌ سِيَرَاءُ فَأَرْسَلَ بِهَا إِلَىَّ فَلَبِسْتُهَا فَأَتَيْتُهُ فَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ وَقَالَ ‏ "‏ إِنِّي لَمْ أُرْسِلْ بِهَا إِلَيْكَ لِتَلْبَسَهَا ‏"‏ ‏.‏ وَأَمَرَنِي فَأَطَرْتُهَا بَيْنَ نِسَائِي ‏.‏\hadithno{4043}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2071)}\hadithtrans{Ali said:A robe containing silk was presented to the Messenger of Allah (ﷺ). He then sent it to me. I wore it and came to him. I saw him looking angry in his face. He then said: I did not send it to you to wear. He ordered me and I divided it among my women}}
\hadithdefcmd{abudawud}{4044}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْقَسِّيِّ وَعَنْ لُبْسِ الْمُعَصْفَرِ وَعَنْ تَخَتُّمِ الذَّهَبِ وَعَنِ الْقِرَاءَةِ فِي الرُّكُوعِ ‏.‏\hadithno{4044}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2078)}\hadithtrans{Narrated 'Ali bin Abi Talib:The Messenger of Allah (ﷺ) forbade us to wear a Qassi garment, a garment dyed with safflower, gold rings, and reading the Qur'an while bowing}}
\hadithdefcmd{abudawud}{4045}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، - يَعْنِي الْمَرْوَزِيَّ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا قَالَ عَنِ الْقِرَاءَةِ فِي الرُّكُوعِ وَالسُّجُودِ ‏.‏\hadithno{4045}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by 'Ali b. Abi Talib from the Prophet (ﷺ) through a different chain of narrators. This version has:(He forbade) reading the Qur'an while bowing and prostrating}}
\hadithdefcmd{abudawud}{4046}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ، بِهَذَا زَادَ وَلاَ أَقُولُ نَهَاكُمْ ‏.‏\hadithno{4046}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ibrahim b. 'Abd Allah through a different chain of narrators. This version added:I do not say that he had forbidden you}}
\hadithdefcmd{abudawud}{4047}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ مَلِكَ الرُّومِ، أَهْدَى إِلَى النَّبِيِّ صلى الله عليه وسلم مُسْتَقَةً مِنْ سُنْدُسٍ فَلَبِسَهَا فَكَأَنِّي أَنْظُرُ إِلَى يَدَيْهِ تَذَبْذَبَانِ ثُمَّ بَعَثَ بِهَا إِلَى جَعْفَرٍ فَلَبِسَهَا ثُمَّ جَاءَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنِّي لَمْ أُعْطِكَهَا لِتَلْبَسَهَا ‏"‏ ‏.‏ قَالَ فَمَا أَصْنَعُ بِهَا قَالَ أَرْسِلْ بِهَا إِلَى أَخِيكَ النَّجَاشِيِّ ‏.‏\hadithno{4047}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The king of Rome presented a fur of silk brocade to the Prophet (ﷺ) and he wore it. The scene that his hands were moving (while wearing the robe) is before my eyes. He then sent it to Ja'far who wore it and came to him. The Prophet (ﷺ) said: I did not send it to you to wear. He asked: What should I do with it? He replied: Send it to your brother Negus}}
\hadithdefcmd{abudawud}{4048}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ أَرْكَبُ الأُرْجُوَانَ وَلاَ أَلْبَسُ الْمُعَصْفَرَ وَلاَ أَلْبَسُ الْقَمِيصَ الْمُكَفَّفَ بِالْحَرِيرِ ‏"‏ ‏.‏ قَالَ وَأَوْمَأَ الْحَسَنُ إِلَى جَيْبِ قَمِيصِهِ ‏.‏ قَالَ وَقَالَ ‏"‏ أَلاَ وَطِيبُ الرِّجَالِ رِيحٌ لاَ لَوْنَ لَهُ أَلاَ وَطِيبُ النِّسَاءِ لَوْنٌ لاَ رِيحَ لَهُ ‏"‏ ‏.‏ قَالَ سَعِيدٌ أُرَاهُ قَالَ إِنَّمَا حَمَلُوا قَوْلَهُ فِي طِيبِ النِّسَاءِ عَلَى أَنَّهَا إِذَا خَرَجَتْ فَأَمَّا إِذَا كَانَتْ عِنْدَ زَوْجِهَا فَلْتَطَّيَّبْ بِمَا شَاءَتْ ‏.‏\hadithno{4048}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) said: I do not ride on purple, or wear a garment dyed with saffron, or wear shirt hemmed with silk. Pointing to the collar of his shirt al-Hasan (al-Basri) said: The perfume used by men should have an odour but no colour, and the perfume used by women should have a colour but no odour. Sa'id said: I think he said: They interpreted his tradition about perfume used by women as applying when she comes out. But when she is with her husband, she may use any perfume she wishes}}
\hadithdefcmd{abudawud}{4049}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، أَخْبَرَنَا الْمُفَضَّلُ، - يَعْنِي ابْنَ فَضَالَةَ - عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْقِتْبَانِيِّ، عَنْ أَبِي الْحُصَيْنِ، - يَعْنِي الْهَيْثَمَ بْنَ شَفِيٍّ - قَالَ خَرَجْتُ أَنَا وَصَاحِبٌ، لِي يُكْنَى أَبَا عَامِرٍ - رَجُلٌ مِنَ الْمَعَافِرِ - لِنُصَلِّيَ بِإِيلْيَاءَ وَكَانَ قَاصَّهُمْ رَجُلٌ مِنَ الأَزْدِ يُقَالُ لَهُ أَبُو رَيْحَانَةَ مِنَ الصَّحَابَةِ قَالَ أَبُو الْحُصَيْنِ فَسَبَقَنِي صَاحِبِي إِلَى الْمَسْجِدِ ثُمَّ رَدِفْتُهُ فَجَلَسْتُ إِلَى جَنْبِهِ فَسَأَلَنِي هَلْ أَدْرَكْتَ قَصَصَ أَبِي رَيْحَانَةَ قُلْتُ لاَ ‏.‏ قَالَ سَمِعْتُهُ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَشْرٍ عَنِ الْوَشْرِ وَالْوَشْمِ وَالنَّتْفِ وَعَنْ مُكَامَعَةِ الرَّجُلِ الرَّجُلَ بِغَيْرِ شِعَارٍ وَعَنْ مُكَامَعَةِ الْمَرْأَةِ الْمَرْأَةَ بِغَيْرِ شِعَارٍ وَأَنْ يَجْعَلَ الرَّجُلُ فِي أَسْفَلِ ثِيَابِهِ حَرِيرًا مِثْلَ الأَعَاجِمِ أَوْ يَجْعَلَ عَلَى مَنْكِبَيْهِ حَرِيرًا مِثْلَ الأَعَاجِمِ وَعَنِ النُّهْبَى وَرُكُوبِ النُّمُورِ وَلُبُوسِ الْخَاتَمِ إِلاَّ لِذِي سُلْطَانٍ ‏.‏ قَالَ أَبُو دَاوُدَ الَّذِي تَفَرَّدَ بِهِ مِنْ هَذَا الْحَدِيثِ ذِكْرُ الْخَاتَمِ ‏.‏\hadithno{4049}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abul Husayn, that is al-Haytham ibn Shafi I and a companion of mine called Abu 'Amir, a man from al-Ma'afir went to perform prayer in Bayt al-Maqdis (Jerusalem). Their preacher was a man of Azd called AbuRayhanah, who was a companion of the Prophet (ﷺ). Abul Husayn said:my companion went to the mosque before me. I went there after him and sat beside him. He asked me: Did you hear the preaching of AbuRayhanah? I said: No. He said: I heard him say: The Messenger of Allah (ﷺ) forbade ten things: Sharpening the ends of the teeth, tattooing, plucking hair, men sleeping together without an under garment, women sleeping together without an under-garment, men putting silk at the hem of their garments like the Persians, or putting silk on their shoulders like the Persians, plundering, riding on panther skins, wearing signet rings, except in the case of one in authority. Abu Dawud said: The solitary point in this tradition (not supported by other traditions) is the report about the signet-ring}}
\hadithdefcmd{abudawud}{4050}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ عُبَيْدَةَ، عَنْ عَلِيٍّ، - رضى الله عنه - أَنَّهُ قَالَ نَهَى عَنْ مَيَاثِرِ الأُرْجُوَانِ ‏.‏\hadithno{4050}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali said:It is forbidden to use purple saddle-clothes}}
\hadithdefcmd{abudawud}{4051}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَالْمِيثَرَةِ الْحَمْرَاءِ ‏.‏\hadithno{4051}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) forbade me to wear a gold ring, or a Qassi garment or the use purple saddle-cloths}}
\hadithdefcmd{abudawud}{4052}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ الزُّهْرِيُّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي خَمِيصَةٍ لَهَا أَعْلاَمٌ فَنَظَرَ إِلَى أَعْلاَمِهَا فَلَمَّا سَلَّمَ قَالَ ‏ "‏ اذْهَبُوا بِخَمِيصَتِي هَذِهِ إِلَى أَبِي جَهْمٍ فَإِنَّهَا أَلْهَتْنِي آنِفًا فِي صَلاَتِي وَأْتُونِي بِأَنْبِجَانِيَّتِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو جَهْمِ بْنُ حُذَيْفَةَ مِنْ بَنِي عَدِيِّ بْنِ كَعْبِ بْنِ غَانِمٍ ‏.‏\hadithno{4052}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5817) Sahih Muslim (556)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) once prayed wearing a garment having marks. He looked at its marks. When he saluted, he said: Take this garment of mine to AbuJahm, for it turned my attention just now in my prayer, and bring a simple garment without marks. Abu Dawud said: The name of Abu Jahm b. Hudhaifah from Banu 'Adi b. Ka'b b. Ghanam}}
\hadithdefcmd{abudawud}{4053}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، نَحْوَهُ وَالأَوَّلُ أَشْبَعُ ‏.‏\hadithno{4053}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (752) Sahih Muslim (556)}\hadithtrans{A similar tradition has also been transmitted by 'Aishah through a different chain of narrators. But the former is more perfect}}
\hadithdefcmd{abudawud}{4054}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الْمُغِيرَةُ بْنُ زِيَادٍ، حَدَّثَنَا عَبْدُ اللَّهِ أَبُو عُمَرَ، مَوْلَى أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ قَالَ رَأَيْتُ ابْنَ عُمَرَ فِي السُّوقِ اشْتَرَى ثَوْبًا شَامِيًّا فَرَأَى فِيهِ خَيْطًا أَحْمَرَ فَرَدَّهُ فَأَتَيْتُ أَسْمَاءَ فَذَكَرْتُ ذَلِكَ لَهَا فَقَالَتْ يَا جَارِيَةُ نَاوِلِينِي جُبَّةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَخْرَجَتْ جُبَّةَ طَيَالِسَةَ مَكْفُوفَةَ الْجَيْبِ وَالْكُمَّيْنِ وَالْفَرْجَيْنِ بِالدِّيبَاجِ ‏.‏\hadithno{4054}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Asma: Abdullah AbuUmar, client of Asma', daughter of AbuBakr, said: I saw Ibn Umar buying a Syrian garment in the market. When he saw that it had red warp, he returned it. I then came to Asma' and mentioned it to her. She said: Bring me, slave-girl, the mantle of the Messenger of Allah (ﷺ). She brought out a mantle of a course ornamented cloth, with its collar, sleeves, front, and back were hemmed with brocade}}
\hadithdefcmd{abudawud}{4055}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا خُصَيْفٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الثَّوْبِ الْمُصْمَتِ مِنَ الْحَرِيرِ فَأَمَّا الْعَلَمُ مِنَ الْحَرِيرِ وَسَدَى الثَّوْبِ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{4055}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas said:It is only a garment wholly made of silk which the Messenger of Allah (ﷺ) forbade, but there is no harm in the ornamented border and the wrap}}
\hadithdefcmd{abudawud}{4056}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَلِلزُّبَيْرِ بْنِ الْعَوَّامِ فِي قُمُصِ الْحَرِيرِ فِي السَّفَرِ مِنْ حِكَّةٍ كَانَتْ بِهِمَا ‏.‏\hadithno{4056}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2919) Sahih Muslim (2076)}\hadithtrans{Narrated Anas:The Messenger of Allah (ﷺ) gave license to 'Abd al-Rahman b. 'Awf and al-Zubair b. al-'Awwam to wear silk shirts during a journey because of an itch which they had}}
\hadithdefcmd{abudawud}{4057}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي أَفْلَحَ الْهَمْدَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ زُرَيْرٍ، - يَعْنِي الْغَافِقِيَّ - أَنَّهُ سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، - رضى الله عنه - يَقُولُ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَخَذَ حَرِيرًا فَجَعَلَهُ فِي يَمِينِهِ وَأَخَذَ ذَهَبًا فَجَعَلَهُ فِي شِمَالِهِ ثُمَّ قَالَ ‏ "‏ إِنَّ هَذَيْنِ حَرَامٌ عَلَى ذُكُورِ أُمَّتِي ‏"‏ ‏.‏\hadithno{4057}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet of Allah (ﷺ) took silk and held it in his right hand, and took gold and held it in his left hand and said: both of these are prohibited to the males of my community}}
\hadithdefcmd{abudawud}{4058}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، وَكَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيَّانِ، قَالاَ حَدَّثَنَا بَقِيَّةُ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ حَدَّثَهُ أَنَّهُ، رَأَى عَلَى أُمِّ كُلْثُومٍ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم بُرْدًا سِيَرَاءَ ‏.‏ قَالَ وَالسِّيَرَاءُ الْمُضَلَّعُ بِالْقَزِّ ‏.‏\hadithno{4058}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas b. Malik said that he saw a striped garment over Umm Kulthum, daughter of the Messenger of Allah (ﷺ). He said:The word "siyara" means striped with silk}}
\hadithdefcmd{abudawud}{4059}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، - يَعْنِي الزُّبَيْرِيَّ - حَدَّثَنَا مِسْعَرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَنْزِعُهُ عَنِ الْغِلْمَانِ، وَنَتْرُكُهُ، عَلَى الْجَوَارِي ‏.‏ قَالَ مِسْعَرٌ فَسَأَلْتُ عَمْرَو بْنَ دِينَارٍ عَنْهُ فَلَمْ يَعْرِفْهُ ‏.‏\hadithno{4059}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: We used to take it away (i.e. silk) from boys, and leave it for girls. Mis'ar said: I asked Amr ibn Dinar about it, but he did not know it}}
\hadithdefcmd{abudawud}{4060}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ قُلْنَا لأَنَسٍ - يَعْنِي ابْنَ مَالِكٍ - أَىُّ اللِّبَاسِ كَانَ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ أَعْجَبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ الْحِبَرَةُ ‏.‏\hadithno{4060}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5812) Sahih Muslim (2079)}\hadithtrans{Narrated Qatadah:We asked Anas b. Malik: Which cloth was dearer to the Messenger of Allah (ﷺ) ? or Which cloth did the Messenger of Allah (ﷺ) like best to wear ? He replied: The striped cloaks (hibrah)}}
\hadithdefcmd{abudawud}{4061}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَسُوا مِنْ ثِيَابِكُمُ الْبَيَاضَ فَإِنَّهَا خَيْرُ ثِيَابِكُمْ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ وَإِنَّ خَيْرَ أَكْحَالِكُمُ الإِثْمِدُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعْرَ ‏"‏ ‏.‏\hadithno{4061}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Wear your white garments, for they are among your best garments, and shroud your dead in them. Among the best types of collyrium you use is antimony (ithmid) for it clears the vision and makes the hair sprout}}
\hadithdefcmd{abudawud}{4062}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مِسْكِينٌ، عَنِ الأَوْزَاعِيِّ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنْ وَكِيعٍ، عَنِ الأَوْزَاعِيِّ، نَحْوَهُ عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَأَى رَجُلاً شَعِثًا قَدْ تَفَرَّقَ شَعْرُهُ فَقَالَ ‏"‏ أَمَا كَانَ يَجِدُ هَذَا مَا يُسَكِّنُ بِهِ شَعْرَهُ ‏"‏ ‏.‏ وَرَأَى رَجُلاً آخَرَ وَعَلَيْهِ ثِيَابٌ وَسِخَةٌ فَقَالَ ‏"‏ أَمَا كَانَ هَذَا يَجِدُ مَاءً يَغْسِلُ بِهِ ثَوْبَهُ ‏"‏ ‏.‏\hadithno{4062}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) paid visit to us, and saw a dishevelled man whose hair was disordered. He said: Could this man not find something to make his hair lie down? He saw another man wearing dirty clothes and said: Could this man not find something to wash his garments with}}
\hadithdefcmd{abudawud}{4063}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي ثَوْبٍ دُونٍ فَقَالَ ‏"‏ أَلَكَ مَالٌ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ مِنْ أَىِّ الْمَالِ ‏"‏ ‏.‏ قَالَ قَدْ أَتَانِيَ اللَّهُ مِنَ الإِبِلِ وَالْغَنَمِ وَالْخَيْلِ وَالرَّقِيقِ ‏.‏ قَالَ ‏"‏ فَإِذَا أَتَاكَ اللَّهُ مَالاً فَلْيُرَ أَثَرُ نِعْمَةِ اللَّهِ عَلَيْكَ وَكَرَامَتِهِ ‏"‏ ‏.‏\hadithno{4063}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu al-Ahwas quoted his father saying:I came to the Prophet (ﷺ) wearing a poor garment and he said (to me): Have you any property? He replied: Yes. He asked: What kind is it? He said: Allah has given me camels. Sheep, horses and slaves. He then said: When Allah gives you property, let the mark of Allah's favour and honour to you be seen}}
\hadithdefcmd{abudawud}{4064}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ زَيْدٍ، - يَعْنِي ابْنَ أَسْلَمَ - أَنَّ ابْنَ عُمَرَ، كَانَ يَصْبُغُ لِحْيَتَهُ بِالصُّفْرَةِ حَتَّى تَمْتَلِئَ ثِيَابُهُ مِنَ الصُّفْرَةِ فَقِيلَ لَهُ لِمَ تَصْبُغُ بِالصُّفْرَةِ فَقَالَ إِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْبُغُ بِهَا وَلَمْ يَكُنْ شَىْءٌ أَحَبَّ إِلَيْهِ مِنْهَا وَقَدْ كَانَ يَصْبُغُ بِهَا ثِيَابَهُ كُلَّهَا حَتَّى عِمَامَتَهُ ‏.‏\hadithno{4064}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zayd ibn Aslam: Ibn Umar used to dye his beard with yellow colour so much so that his clothes were filled (dyed) with yellowness. He was asked: Why do you dye with yellow colour? He replied: I saw the Messenger of Allah (ﷺ) dyeing with yellow colour, and nothing was dearer to him than it. He would dye all his clothes with it, even his turban}}
\hadithdefcmd{abudawud}{4065}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ إِيَادٍ - حَدَّثَنَا إِيَادٌ، عَنْ أَبِي رِمْثَةَ، قَالَ انْطَلَقْتُ مَعَ أَبِي نَحْوَ النَّبِيِّ صلى الله عليه وسلم فَرَأَيْتُ عَلَيْهِ بُرْدَيْنِ أَخْضَرَيْنِ ‏.‏\hadithno{4065}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuRimthah: I went with my father to the Prophet (ﷺ) and saw two green garments over him}}
\hadithdefcmd{abudawud}{4066}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامُ بْنُ الْغَازِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ هَبَطْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ ثَنِيَّةٍ فَالْتَفَتَ إِلَىَّ وَعَلَىَّ رَيْطَةٌ مُضَرَّجَةٌ بِالْعُصْفُرِ فَقَالَ ‏"‏ مَا هَذِهِ الرَّيْطَةُ عَلَيْكَ ‏"‏ ‏.‏ فَعَرَفْتُ مَا كَرِهَ فَأَتَيْتُ أَهْلِي وَهُمْ يَسْجُرُونَ تَنُّورًا لَهُمْ فَقَذَفْتُهَا فِيهِ ثُمَّ أَتَيْتُهُ مِنَ الْغَدِ فَقَالَ ‏"‏ يَا عَبْدَ اللَّهِ مَا فَعَلَتِ الرَّيْطَةُ ‏"‏ ‏.‏ فَأَخْبَرْتُهُ فَقَالَ ‏"‏ أَلاَ كَسَوْتَهَا بَعْضَ أَهْلِكَ فَإِنَّهُ لاَ بَأْسَ بِهِ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{4066}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather said: We came down with the Messenger of Allah (ﷺ) from a turning of a valley. He turned his attention to me and I was wearing a garment dyed with a reddish yellow dye. He asked: What is this garment over you? I recognised what he disliked. I then came to my family who were burning their oven. I threw it (the garment) in it and came to him the next day. He asked: Abdullah, what have you done with the garment? I informed him about it. He said: Why did you not give it to one of your family to wear, for there is no harm in it for women}}
\hadithdefcmd{abudawud}{4067}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ الْحِمْصِيُّ، حَدَّثَنَا الْوَلِيدُ، قَالَ قَالَ هِشَامٌ - يَعْنِي ابْنَ الْغَازِ - الْمُضَرَّجَةُ الَّتِي لَيْسَتْ بِمُشَبَّعَةٍ وَلاَ الْمُوَرَّدَةُ ‏.‏\hadithno{4067}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Hisham b. al-Ghaz said:The word mudarrajah mentioned in the previous tradition means a colour which is neither crimson nor pink}}
\hadithdefcmd{abudawud}{4068}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ شُرَحْبِيلَ بْنِ مُسْلِمٍ، عَنْ شُفْعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ رَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ أَبُو عَلِيٍّ اللُّؤْلُؤِيُّ أُرَاهُ - وَعَلَىَّ ثَوْبٌ مَصْبُوغٌ بِعُصْفُرٍ مُوَرَّدٍ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَانْطَلَقْتُ فَأَحْرَقْتُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا صَنَعْتَ بِثَوْبِكَ ‏"‏ ‏.‏ فَقُلْتُ أَحْرَقْتُهُ ‏.‏ قَالَ ‏"‏ أَفَلاَ كَسَوْتَهُ بَعْضَ أَهْلِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ثَوْرٌ عَنْ خَالِدٍ فَقَالَ مُوَرَّدٌ وَطَاوُسٌ قَالَ مُعَصْفَرٌ ‏.‏\hadithno{4068}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) saw me. The version of AbuAli al-Lula' has: I think I wore a garment dyed with a reddish yellow colour. He asked: What is this? So I went and burnt it. The Prophet (ﷺ) said: What have you done with your garment? I replied: I burnt it. He said: Why did you not give it to one of your women to wear? Abu Dawud said: Thawr transmitted it from Khalid and said: "Pink (muwarrad)" while Tawus said: "Reddish yellow colour (mu'asfar)}}
\hadithdefcmd{abudawud}{4069}{حَدَّثَنَا مُحَمَّدُ بْنُ حُزَابَةَ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ مَنْصُورٍ - حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي يَحْيَى، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ مَرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم رَجُلٌ عَلَيْهِ ثَوْبَانِ أَحْمَرَانِ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِ ‏.‏\hadithno{4069}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: A man wearing two red garments passed the Prophet (ﷺ) and gave him a greeting, but he did not respond to his greeting}}
\hadithdefcmd{abudawud}{4070}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، - يَعْنِي ابْنَ كَثِيرٍ - عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ رَجُلٍ، مِنْ بَنِي حَارِثَةَ عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَوَاحِلِنَا وَعَلَى إِبِلِنَا أَكْسِيَةً فِيهَا خُيُوطُ عِهْنٍ حُمْرٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أَرَى هَذِهِ الْحُمْرَةَ قَدْ عَلَتْكُمْ ‏"‏ ‏.‏ فَقُمْنَا سِرَاعًا لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى نَفَرَ بَعْضُ إِبِلِنَا فَأَخَذْنَا الأَكْسِيَةَ فَنَزَعْنَاهَا عَنْهَا ‏.‏\hadithno{4070}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' ibn Khadij: We went out with the Messenger of Allah (ﷺ) on a journey, and we had on our saddles and camels garments consisting of red warp of wool. The Messenger of Allah (ﷺ) said: Do I not see that red colour has dominated you. We then got up quickly on account of this saying of the Messenger of Allah (ﷺ) and some of our camels ran away. We then took the garments and withdrew them}}
\hadithdefcmd{abudawud}{4071}{حَدَّثَنَا ابْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنِي أَبِي، - قَالَ ابْنُ عَوْفٍ الطَّائِيُّ وَقَرَأْتُ فِي أَصْلِ إِسْمَاعِيلَ - قَالَ حَدَّثَنِي ضَمْضَمٌ - يَعْنِي ابْنَ زُرْعَةَ - عَنْ شُرَيْحِ بْنِ عُبَيْدٍ عَنْ حَبِيبِ بْنِ عُبَيْدٍ عَنْ حُرَيْثِ بْنِ الأَبَحِّ السَّلِيحِيِّ أَنَّ امْرَأَةً مِنْ بَنِي أَسَدٍ قَالَتْ كُنْتُ يَوْمًا عِنْدَ زَيْنَبَ امْرَأَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَصْبُغُ ثِيَابًا لَهَا بِمَغْرَةٍ فَبَيْنَا نَحْنُ كَذَلِكَ إِذْ طَلَعَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَى الْمَغْرَةَ رَجَعَ فَلَمَّا رَأَتْ ذَلِكَ زَيْنَبُ عَلِمَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ كَرِهَ مَا فَعَلَتْ فَأَخَذَتْ فَغَسَلَتْ ثِيَابَهَا وَوَارَتْ كُلَّ حُمْرَةٍ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَجَعَ فَاطَّلَعَ فَلَمَّا لَمْ يَرَ شَيْئًا دَخَلَ ‏.‏\hadithno{4071}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hurayth ibn al-Abajj as-Sulayhi: That a woman of Banu Asad: One day I was with Zaynab, the wife of the Messenger of Allah (ﷺ), and we were dyeing her clothes with red ochre. In the meantime the Messenger of Allah (ﷺ) peeped us. When he saw the red ochre, he returned. When Zaynab saw this, she realised that the Messenger of Allah (ﷺ) disapproved of what she had done. She then took and washed her clothes and concealed all redness. The Messenger of Allah (ﷺ) then returned and peeped, and when he did not see anything, he entered}}
\hadithdefcmd{abudawud}{4072}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَهُ شَعْرٌ يَبْلُغُ شَحْمَةَ أُذُنَيْهِ وَرَأَيْتُهُ فِي حُلَّةٍ حَمْرَاءَ لَمْ أَرَ شَيْئًا قَطُّ أَحْسَنَ مِنْهُ ‏.‏\hadithno{4072}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3551) Sahih Muslim (2337)}\hadithtrans{Narrated Al-Bara' bin 'Azib:The Messenger of Allah (ﷺ) had hair which reached the lobes of his ears, and I saw him wearing red robe. I did not see anything more beautiful than it}}
\hadithdefcmd{abudawud}{4073}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِلاَلِ بْنِ عَامِرٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِمِنًى يَخْطُبُ عَلَى بَغْلَةٍ وَعَلَيْهِ بُرْدٌ أَحْمَرُ وَعَلِيٌّ - رضى الله عنه - أَمَامَهُ يُعَبِّرُ عَنْهُ ‏.‏\hadithno{4073}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Amir: I saw the Messenger of Allah (ﷺ) at Mina giving sermon on a mule and wearing a red garment, while Ali was announcing}}
\hadithdefcmd{abudawud}{4074}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ صَنَعْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم بُرْدَةً سَوْدَاءَ فَلَبِسَهَا فَلَمَّا عَرَقَ فِيهَا وَجَدَ رِيحَ الصُّوفِ فَقَذَفَهَا ‏.‏ قَالَ وَأَحْسِبُهُ قَالَ وَكَانَ تُعْجِبُهُ الرِّيحُ الطَّيِّبَةُ ‏.‏\hadithno{4074}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I made a black cloak for the Prophet (ﷺ) and he put it on; but when he sweated in it and noticed the odour of the wool, he threw it away. The narrator said: I think he said: He liked good smell}}
\hadithdefcmd{abudawud}{4075}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ عُبَيْدَةَ أَبِي خِدَاشٍ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، عَنْ جَابِرٍ، - يَعْنِي ابْنَ سُلَيْمٍ - قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ مُحْتَبٍ بِشَمْلَةٍ وَقَدْ وَقَعَ هُدْبُهَا عَلَى قَدَمَيْهِ ‏.‏\hadithno{4075}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: When I came to the Prophet (ﷺ), he was sitting with his hands round his knees wearing the cloak the fringe of which was over his feet}}
\hadithdefcmd{abudawud}{4076}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالُوا حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَامَ الْفَتْحِ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{4076}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) entered Mecca in the year of the Conquest while he had a black turben over him}}
\hadithdefcmd{abudawud}{4077}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُسَاوِرٍ الْوَرَّاقِ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ قَدْ أَرْخَى طَرَفَيْهَا بَيْنَ كَتِفَيْهِ ‏.‏\hadithno{4077}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1359)}\hadithtrans{Amr b. Huraith quoting his father said:I saw the Prophet (ﷺ) on the pulpit and he wore a black turban, and he let both the ends hang between his shoulders}}
\hadithdefcmd{abudawud}{4078}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، حَدَّثَنَا أَبُو الْحَسَنِ الْعَسْقَلاَنِيُّ، عَنْ أَبِي جَعْفَرِ بْنِ مُحَمَّدِ بْنِ عَلِيِّ بْنِ رُكَانَةَ، عَنْ أَبِيهِ، أَنَّ رُكَانَةَ، صَارَعَ النَّبِيَّ صلى الله عليه وسلم فَصَرَعَهُ النَّبِيُّ صلى الله عليه وسلم قَالَ رُكَانَةُ وَسَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ فَرْقُ مَا بَيْنَنَا وَبَيْنَ الْمُشْرِكِينَ الْعَمَائِمُ عَلَى الْقَلاَنِسِ ‏"‏ ‏.‏\hadithno{4078}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn Rukanah: Ali quoting his father said: Rukanah wrestled with the Prophet (ﷺ) and the Prophet (ﷺ) threw him on the ground. Rukanah said: I heard the Prophet (ﷺ) say: The difference between us and the polytheists is that we wear turbans over caps}}
\hadithdefcmd{abudawud}{4079}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، مَوْلَى بَنِي هَاشِمٍ حَدَّثَنَا عُثْمَانُ بْنُ عُثْمَانَ الْغَطَفَانِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ خَرَّبُوذَ، حَدَّثَنِي شَيْخٌ، مِنْ أَهْلِ الْمَدِينَةِ قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، يَقُولُ عَمَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَدَلَهَا بَيْنَ يَدَىَّ وَمِنْ خَلْفِي ‏.‏\hadithno{4079}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman ibn Awf: The Messenger of Allah (ﷺ) put a turban on me and let the ends hang in front of him and behind me}}
\hadithdefcmd{abudawud}{4080}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لِبْسَتَيْنِ أَنْ يَحْتَبِيَ الرَّجُلُ مُفْضِيًا بِفَرْجِهِ إِلَى السَّمَاءِ وَيَلْبَسَ ثَوْبَهُ وَأَحَدُ جَانِبَيْهِ خَارِجٌ وَيُلْقِي ثَوْبَهُ عَلَى عَاتِقِهِ ‏.‏\hadithno{4080}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) forbade wearing clothes in two styles: that a man sits in a single garment with his hands round his knees and uncover his private parts towards heaven and that he wears his garment while one of his sides is uncovered, and puts the garment on his shoulders}}
\hadithdefcmd{abudawud}{4081}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الصَّمَّاءِ وَعَنْ الاِحْتِبَاءِ فِي ثَوْبٍ وَاحِدٍ ‏.‏\hadithno{4081}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2099)}\hadithtrans{Narrated Jabir:The Messenger of Allah (ﷺ) forbade that a man should wrap himself completely in a garment with his hands hidden it, or sit in a single garment with his hands round his knees}}
\hadithdefcmd{abudawud}{4082}{حَدَّثَنَا النُّفَيْلِيُّ، وَأَحْمَدُ بْنُ يُونُسَ، قَالاَ حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عُرْوَةُ بْنُ عَبْدِ اللَّهِ، - قَالَ ابْنُ نُفَيْلٍ ابْنُ قُشَيْرٍ أَبُو مَهَلٍ الْجُعْفِيُّ - حَدَّثَنَا مُعَاوِيَةُ بْنُ قُرَّةَ، حَدَّثَنِي أَبِي قَالَ، أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ مِنْ مُزَيْنَةَ فَبَايَعْنَاهُ وَإِنَّ قَمِيصَهُ لَمُطْلَقُ الأَزْرَارِ - قَالَ - فَبَايَعْتُهُ ثُمَّ أَدْخَلْتُ يَدِي فِي جَيْبِ قَمِيصِهِ فَمَسِسْتُ الْخَاتَمَ ‏.‏ قَالَ عُرْوَةُ فَمَا رَأَيْتُ مُعَاوِيَةَ وَلاَ ابْنَهُ قَطُّ إِلاَّ مُطْلِقِي أَزْرَارِهِمَا فِي شِتَاءٍ وَلاَ حَرٍّ وَلاَ يُزَرِّرَانِ أَزْرَارَهُمَا أَبَدًا ‏.‏\hadithno{4082}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'awiyah b. Qurrah quoted his father as saying:I came to the Messenger of Allah (ﷺ) with a company of Muzainah and we swore allegiance to him. The buttons of his shirt were open. I swore allegiance to him and I put my hand inside the collar of his shirt and felt the seal. 'Urwah said: I always saw Mu'awiyah and his son opening their buttons of the collar during winter and summer. They never closed their buttons}}
\hadithdefcmd{abudawud}{4083}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ قَالَ الزُّهْرِيُّ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ رضى الله عنها بَيْنَا نَحْنُ جُلُوسٌ فِي بَيْتِنَا فِي نَحْرِ الظَّهِيرَةِ قَالَ قَائِلٌ لأَبِي بَكْرٍ رضى الله عنه هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُقْبِلاً مُتَقَنِّعًا فِي سَاعَةٍ لَمْ يَكُنْ يَأْتِينَا فِيهَا فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَأْذَنَ فَأُذِنَ لَهُ فَدَخَلَ ‏.‏\hadithno{4083}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:We were seated in our house in the noonday heat. Someone said to Abu Bakr: Here is the Messenger of Allah (ﷺ) coming to us shading his head at the hour when he would not generally come. The Messenger of Allah (ﷺ) then came; he asked for permission and he gave him permission and he entered}}
\hadithdefcmd{abudawud}{4084}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي غِفَارٍ، حَدَّثَنَا أَبُو تَمِيمَةَ الْهُجَيْمِيُّ، - وَأَبُو تَمِيمَةَ اسْمُهُ طَرِيفُ بْنُ مُجَالِدٍ - عَنْ أَبِي جُرَىٍّ، جَابِرِ بْنِ سُلَيْمٍ قَالَ رَأَيْتُ رَجُلاً يَصْدُرُ النَّاسُ عَنْ رَأْيِهِ، لاَ يَقُولُ شَيْئًا إِلاَّ صَدَرُوا عَنْهُ قُلْتُ مَنْ هَذَا قَالُوا هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْتُ عَلَيْكَ السَّلاَمُ يَا رَسُولَ اللَّهِ مَرَّتَيْنِ ‏.‏ قَالَ ‏"‏ لاَ تَقُلْ عَلَيْكَ السَّلاَمُ ‏.‏ فَإِنَّ عَلَيْكَ السَّلاَمُ تَحِيَّةُ الْمَيِّتِ قُلِ السَّلاَمُ عَلَيْكَ ‏"‏ ‏.‏ قَالَ قُلْتُ أَنْتَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَنَا رَسُولُ اللَّهِ الَّذِي إِذَا أَصَابَكَ ضُرٌّ فَدَعَوْتَهُ كَشَفَهُ عَنْكَ وَإِنْ أَصَابَكَ عَامُ سَنَةٍ فَدَعَوْتَهُ أَنْبَتَهَا لَكَ وَإِذَا كُنْتَ بِأَرْضٍ قَفْرَاءَ أَوْ فَلاَةٍ فَضَلَّتْ رَاحِلَتُكَ فَدَعَوْتَهُ رَدَّهَا عَلَيْكَ ‏"‏ ‏.‏ قُلْتُ اعْهَدْ إِلَىَّ ‏.‏ قَالَ ‏"‏ لاَ تَسُبَّنَّ أَحَدًا ‏"‏ ‏.‏ قَالَ فَمَا سَبَبْتُ بَعْدَهُ حُرًّا وَلاَ عَبْدًا وَلاَ بَعِيرًا وَلاَ شَاةً ‏.‏ قَالَ ‏"‏ وَلاَ تَحْقِرَنَّ شَيْئًا مِنَ الْمَعْرُوفِ وَأَنْ تُكَلِّمَ أَخَاكَ وَأَنْتَ مُنْبَسِطٌ إِلَيْهِ وَجْهُكَ إِنَّ ذَلِكَ مِنَ الْمَعْرُوفِ وَارْفَعْ إِزَارَكَ إِلَى نِصْفِ السَّاقِ فَإِنْ أَبَيْتَ فَإِلَى الْكَعْبَيْنِ وَإِيَّاكَ وَإِسْبَالَ الإِزَارِ فَإِنَّهَا مِنَ الْمَخِيلَةِ وَإِنَّ اللَّهَ لاَ يُحِبُّ الْمَخِيلَةَ وَإِنِ امْرُؤٌ شَتَمَكَ وَعَيَّرَكَ بِمَا يَعْلَمُ فِيكَ فَلاَ تُعَيِّرْهُ بِمَا تَعْلَمُ فِيهِ فَإِنَّمَا وَبَالُ ذَلِكَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4084}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuJurayy Jabir ibn Salim al-Hujaymi: I saw a man whose opinion was accepted by the people, and whatever he said they submitted to it. I asked: Who is he? They said: This is the Messenger of Allah (ﷺ). I said: On you be peace, Messenger of Allah, twice. He said: Do not say "On you be peace," for "On you be peace" is a greeting for the dead, but say "Peace be upon you". I asked: You are the Messenger of Allah (may peace be upon you)? He said: I am the Messenger of Allah Whom you call when a calamity befalls you and He removes it; when you suffer from drought and you call Him, He grows food for you; and when you are in a desolate land or in a desert and your she-camel strays and you call Him, He returns it to you. I said: Give me some advice. He said: Do not abuse anyone. He said that he did not abuse a freeman, or a slave, or a camel or a sheep thenceforth. He said: Do not look down upon any good work, and when you speak to your brother, show him a cheerful face. This is a good work. Have your lower garment halfway down your shin; if you cannot do it, have it up to the ankles. Beware of trailing the lower garment, for it is conceit and Allah does not like conceit. And if a man abuses and shames you for something which he finds in you, then do not shame him for something which you find in him; he will bear the evil consequences for it}}
\hadithdefcmd{abudawud}{4085}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّ أَحَدَ جَانِبَىْ إِزَارِي يَسْتَرْخِي إِنِّي لأَتَعَاهَدُ ذَلِكَ مِنْهُ ‏.‏ قَالَ ‏"‏ لَسْتَ مِمَّنْ يَفْعَلُهُ خُيَلاَءَ ‏"‏ ‏.‏\hadithno{4085}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5784)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) as saying: If anyone trails his garment arrogantly, Allah will not look at him on the Day of Resurrection. Then Abu Bakr said: One of the sides of my lower garment trails, but still I remain careful about it. He said: You are not one of those who do so conceitedly}}
\hadithdefcmd{abudawud}{4086}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي جَعْفَرٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا رَجُلٌ يُصَلِّي مُسْبِلاً إِزَارَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبْ فَتَوَضَّأْ ‏"‏ ‏.‏ فَذَهَبَ فَتَوَضَّأَ ثُمَّ جَاءَ ثُمَّ قَالَ ‏"‏ اذْهَبْ فَتَوَضَّأْ ‏"‏ ‏.‏ فَقَالَ لَهُ رَجُلٌ يَا رَسُولَ اللَّهِ مَا لَكَ أَمَرْتَهُ أَنْ يَتَوَضَّأَ ثُمَّ سَكَتَّ عَنْهُ قَالَ ‏"‏ إِنَّهُ كَانَ يُصَلِّي وَهُوَ مُسْبِلٌ إِزَارَهُ وَإِنَّ اللَّهَ لاَ يَقْبَلُ صَلاَةَ رَجُلٍ مُسْبِلٍ ‏"‏ ‏.‏\hadithno{4086}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:A man was praying with his lower garment hanging down. The Messenger of Allah (ﷺ) said to him: Go and perform ablution. He then went and performed ablution. He then came and he said: Go and perform ablution. Then a man said to him: Messenger of Allah, what is the matter with you that you commanded him to perform ablution and then you kept silence ? He replied: He was praying while hanging down his lower garments, and Allah does not accept the prayer of a man who hangs down his lower garment}}
\hadithdefcmd{abudawud}{4087}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ وَلاَ يَنْظُرُ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏ قُلْتُ مَنْ هُمْ يَا رَسُولَ اللَّهِ قَدْ خَابُوا وَخَسِرُوا أَعَادَهَا ثَلاَثًا ‏.‏ قُلْتُ مَنْ هُمْ يَا رَسُولَ اللَّهِ خَابُوا وَخَسِرُوا فَقَالَ ‏"‏ الْمُسْبِلُ وَالْمَنَّانُ وَالْمُنْفِقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ ‏"‏ ‏.‏ أَوِ ‏"‏ الْفَاجِرِ ‏"‏ ‏.‏\hadithno{4087}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (106)}\hadithtrans{Narrated Abu Dharr:The Prophet (ﷺ) as saying: There are three to whom Allah will not speak and at whom He will not look on the Day of Resurrection, and whom He will not declare pure, and they will have a painful punishment. I asked: Who are they, Messenger of Allah, they are losers and disappointed ? He repeated it three times. I asked: Who are they. Messenger of Allah, they are losers and disappointed ? He replied: The one who wears a trailing robe, the one who takes account of what he gives, and the one who produces a ready sale of a commodity by false swearing}}
\hadithdefcmd{abudawud}{4088}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ سُلَيْمَانَ بْنِ مُسْهِرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا وَالأَوَّلُ أَتَمُّ قَالَ ‏ "‏ الْمَنَّانُ الَّذِي لاَ يُعْطِي شَيْئًا إِلاَّ مَنَّهُ ‏"‏ ‏.‏\hadithno{4088}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (106)}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Dharr though a different chain of narrators, but the former is more perfect. This version has:Mannan is the one takes account of anything he gives}}
\hadithdefcmd{abudawud}{4089}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو عَامِرٍ، - يَعْنِي عَبْدَ الْمَلِكِ بْنَ عَمْرٍو - حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ قَيْسِ بْنِ بِشْرٍ التَّغْلِبِيِّ، قَالَ أَخْبَرَنِي أَبِي، - وَكَانَ جَلِيسًا لأَبِي الدَّرْدَاءِ - قَالَ كَانَ بِدِمَشْقَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهُ ابْنُ الْحَنْظَلِيَّةِ وَكَانَ رَجُلاً مُتَوَحِّدًا قَلَّمَا يُجَالِسُ النَّاسَ إِنَّمَا هُوَ صَلاَةٌ فَإِذَا فَرَغَ فَإِنَّمَا هُوَ تَسْبِيحٌ وَتَكْبِيرٌ حَتَّى يَأْتِيَ أَهْلَهُ فَمَرَّ بِنَا وَنَحْنُ عِنْدَ أَبِي الدَّرْدَاءِ فَقَالَ لَهُ أَبُو الدَّرْدَاءِ كَلِمَةً تَنْفَعُنَا وَلاَ تَضُرُّكَ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً فَقَدِمَتْ فَجَاءَ رَجُلٌ مِنْهُمْ فَجَلَسَ فِي الْمَجْلِسِ الَّذِي يَجْلِسُ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لِرَجُلٍ إِلَى جَنْبِهِ لَوْ رَأَيْتَنَا حِينَ الْتَقَيْنَا نَحْنُ وَالْعَدُوُّ فَحَمَلَ فُلاَنٌ فَطَعَنَ فَقَالَ خُذْهَا مِنِّي وَأَنَا الْغُلاَمُ الْغِفَارِيُّ كَيْفَ تَرَى فِي قَوْلِهِ قَالَ مَا أُرَاهُ إِلاَّ قَدْ بَطَلَ أَجْرُهُ فَسَمِعَ بِذَلِكَ آخَرُ فَقَالَ مَا أَرَى بِذَلِكَ بَأْسًا فَتَنَازَعَا حَتَّى سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ لاَ بَأْسَ أَنْ يُؤْجَرَ وَيُحْمَدَ ‏"‏ ‏.‏ فَرَأَيْتُ أَبَا الدَّرْدَاءِ سُرَّ بِذَلِكَ وَجَعَلَ يَرْفَعُ رَأْسَهُ إِلَيْهِ وَيَقُولُ أَنْتَ سَمِعْتَ ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَقُولُ نَعَمْ ‏.‏ فَمَا زَالَ يُعِيدُ عَلَيْهِ حَتَّى إِنِّي لأَقُولُ لَيَبْرُكَنَّ عَلَى رُكْبَتَيْهِ ‏.‏ قَالَ فَمَرَّ بِنَا يَوْمًا آخَرَ فَقَالَ لَهُ أَبُو الدَّرْدَاءِ كَلِمَةً تَنْفَعُنَا وَلاَ تَضُرُّكَ قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُنْفِقُ عَلَى الْخَيْلِ كَالْبَاسِطِ يَدَهُ بِالصَّدَقَةِ لاَ يَقْبِضُهَا ‏"‏ ‏.‏ ثُمَّ مَرَّ بِنَا يَوْمًا آخَرَ فَقَالَ لَهُ أَبُو الدَّرْدَاءِ كَلِمَةً تَنْفَعُنَا وَلاَ تَضُرُّكَ ‏.‏ قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نِعْمَ الرَّجُلُ خُرَيْمٌ الأَسَدِيُّ لَوْلاَ طُولُ جُمَّتِهِ وَإِسْبَالُ إِزَارِهِ ‏"‏ ‏.‏ فَبَلَغَ ذَلِكَ خُرَيْمًا فَعَجِلَ فَأَخَذَ شَفْرَةً فَقَطَعَ بِهَا جُمَّتَهُ إِلَى أُذُنَيْهِ وَرَفَعَ إِزَارَهُ إِلَى أَنْصَافِ سَاقَيْهِ ‏.‏ ثُمَّ مَرَّ بِنَا يَوْمًا آخَرَ فَقَالَ لَهُ أَبُو الدَّرْدَاءِ كَلِمَةً تَنْفَعُنَا وَلاَ تَضُرُّكَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّكُمْ قَادِمُونَ عَلَى إِخْوَانِكُمْ فَأَصْلِحُوا رِحَالَكُمْ وَأَصْلِحُوا لِبَاسَكُمْ حَتَّى تَكُونُوا كَأَنَّكُمْ شَامَةٌ فِي النَّاسِ فَإِنَّ اللَّهَ لاَ يُحِبُّ الْفُحْشَ وَلاَ التَّفَحُّشَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ قَالَ أَبُو نُعَيْمٍ عَنْ هِشَامٍ قَالَ حَتَّى تَكُونُوا كَالشَّامَةِ فِي النَّاسِ ‏.‏\hadithno{4089}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Qays ibn Bishr at-Taghlibi: My father told me that he was a companion of Abu Darda'. There was in Damascus a man from the companions of the Prophet (ﷺ), called Ibn al-Hanzaliyyah. He was a recluse and rarely met the people. He remained engaged in prayer. When he was not praying he was occupied in glorifying Allah and exalting Him until he went to his family. Once he passed us when we were with AbudDarda'. AbudDarda' said to him: Tell us a word which benefits us and does not harm you. He said: The Messenger of Allah (ﷺ) sent out a contingent and it came back. One of the men came and sat in the place where the Messenger of Allah (ﷺ) used to sit, and he said to a man beside him: Would that you saw us when we met the enemy and so-and-so attacked and cut through a lance. He said: Take it from me and I am a boy of the tribe Ghifar. What do you think about his statement? He replied: I think his reward was lost. Another man heard it and said: I do not think that there is any harm in it. They quarrelled until the Messenger of Allah (ﷺ) heard it, and he said: Glory be to Allah! There is no harm if he is rewarded and praised. I saw that AbudDarda' was pleased with it and began to raise his hand to him and say: Did you hear it from the Messenger of Allah (ﷺ)? He said: Yes. He continued to repeat it to him so often that I thought he was going to kneel down. He said: On another day he again passed us. AbudDarda' said to him: (Tell us) a word which benefits us and does not harm you. He said: The Messenger of Allah (ﷺ) said to us: One who spends on (the maintenance of) horses (for jihad) is like the one who spreads his hand to give alms (sadaqah) and does not withhold it. He then passed us on another day. AbudDarda' said to him: (Tell us) a word which benefits us and does no harm to you. He said: The Messenger of Allah (ﷺ) said: Khuraym al-Asadi would be a fine man were it not for the length of his hair, which reaches the shoulders, and the way he lets his lower garment hang down. When Khuraym heard that, he hurriedly, took a knife, cut his hair in line with his ears and raised his lower garment half way up his legs. He then passed us on another day. AbudDarda' said to him: (tell us) a word which benefits us and does not harm you. He said: I heard the Messenger of Allah (ﷺ) say: You are coming to your brethren; so tidy your mounts and tidy your dress, until you are like a mole among the people. Allah does not like obscene words or deeds, or do intentional committing of obscenity. Abu Dawud said: Similarly, Abu Nu'aim narrated from Hisham. He said: Until you will be like a mole among the people}}
\hadithdefcmd{abudawud}{4090}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا هَنَّادٌ، - يَعْنِي ابْنَ السَّرِيِّ - عَنْ أَبِي الأَحْوَصِ، - الْمَعْنَى - عَنْ عَطَاءِ بْنِ السَّائِبِ، قَالَ مُوسَى عَنْ سَلْمَانَ الأَغَرِّ، - وَقَالَ هَنَّادٌ عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، - عَنْ أَبِي هُرَيْرَةَ، - قَالَ هَنَّادٌ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ الْكِبْرِيَاءُ رِدَائِي وَالْعَظَمَةُ إِزَارِي فَمَنْ نَازَعَنِي وَاحِدًا مِنْهُمَا قَذَفْتُهُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4090}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Allah Most High says: Pride is my cloak and majesty is my lower garment, and I shall throw him who view with me regarding one of them into Hell}}
\hadithdefcmd{abudawud}{4091}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو بَكْرٍ، - يَعْنِي ابْنَ عَيَّاشٍ - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ كِبْرٍ وَلاَ يَدْخُلُ النَّارَ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ خَرْدَلَةٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْقَسْمَلِيُّ عَنِ الأَعْمَشِ مِثْلَهُ ‏.‏\hadithno{4091}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (91)}\hadithtrans{Narrated 'Abd Allah (b. Mas'ud): The Messenger of Allah (ﷺ) as saying: He who has in his heart as much pride as much pride as grain of mustard-seed will not enter paradise. And he who has in his heart as much faith as grain of mustard-seed will not enter Hell. Abu Dawud said: Al-Qasmali has transmitted it from Al-A'mash in a similar way}}
\hadithdefcmd{abudawud}{4092}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم - وَكَانَ رَجُلاً جَمِيلاً - فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ حُبِّبَ إِلَىَّ الْجَمَالُ وَأُعْطِيتُ مِنْهُ مَا تَرَى حَتَّى مَا أُحِبُّ أَنْ يَفُوقَنِي أَحَدٌ - إِمَّا قَالَ بِشِرَاكِ نَعْلِي ‏.‏ وَإِمَّا قَالَ بِشِسْعِ نَعْلِي - أَفَمِنَ الْكِبْرِ ذَلِكَ قَالَ ‏ "‏ لاَ وَلَكِنَّ الْكِبْرَ مَنْ بَطَرَ الْحَقَّ وَغَمَطَ النَّاسَ ‏"‏ ‏.‏\hadithno{4092}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: A man who was beautiful came to the Prophet (ﷺ). He said: Messenger of Allah, I am a man who likes beauty, and I have been given some of it, as you see. And I do not like that anyone excels me (in respect of beauty). Perhaps he said: "even to the extent of thong of my sandal (shirak na'li)", or he he said: "to the extent of strap of my sandal (shis'i na'li)". Is it pride? He replied: No, pride is disdaining what is true and despising people}}
\hadithdefcmd{abudawud}{4093}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ عَنِ الإِزَارِ، فَقَالَ عَلَى الْخَبِيرِ سَقَطْتَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِزْرَةُ الْمُسْلِمِ إِلَى نِصْفِ السَّاقِ وَلاَ حَرَجَ - أَوْ لاَ جُنَاحَ - فِيمَا بَيْنَهُ وَبَيْنَ الْكَعْبَيْنِ مَا كَانَ أَسْفَلَ مِنَ الْكَعْبَيْنِ فَهُوَ فِي النَّارِ مَنْ جَرَّ إِزَارَهُ بَطَرًا لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ ‏"‏ ‏.‏\hadithno{4093}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdur Rahman: I asked Abu Sa'id al-Khudri about wearing lower garment. He said: You have come to the man who knows it very well. The Messenger of Allah (ﷺ) said: The way for a believer to wear a lower garment is to have it halfway down his legs and he is guilty of no sin if it comes halfway between that and the ankles, but what comes lower than the ankles is in Hell. On the day of Resurrection. Allah will not look at him who trails his lower garment conceitedly}}
\hadithdefcmd{abudawud}{4094}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي رَوَّادٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الإِسْبَالُ فِي الإِزَارِ وَالْقَمِيصِ وَالْعِمَامَةِ مَنْ جَرَّ مِنْهَا شَيْئًا خُيَلاَءَ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4094}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: Hanging down is in lower garment, shirt and turban. If anyone trails any of them conceitedly, Allah will not look at him on the Day of Resurrection}}
\hadithdefcmd{abudawud}{4095}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ أَبِي الصَّبَّاحِ، عَنْ يَزِيدَ بْنِ أَبِي سُمَيَّةَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الإِزَارِ فَهُوَ فِي الْقَمِيصِ ‏.‏\hadithno{4095}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: What the Messenger of Allah (ﷺ) said about lower garment also applies to shirt}}
\hadithdefcmd{abudawud}{4096}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ أَبِي يَحْيَى، قَالَ حَدَّثَنِي عِكْرِمَةُ، أَنَّهُ رَأَى ابْنَ عَبَّاسٍ يَأْتَزِرُ فَيَضَعُ حَاشِيَةَ إِزَارِهِ مِنْ مُقَدَّمِهِ عَلَى ظَهْرِ قَدَمَيْهِ وَيَرْفَعُ مِنْ مُؤَخَّرِهِ ‏.‏ قُلْتُ لِمَ تَأْتَزِرُ هَذِهِ الإِزْرَةَ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْتَزِرُهَا ‏.‏\hadithno{4096}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ikrimah said that he saw Ibn Abbas putting on lower garment, letting the hem on the top of his foot and raising it behind. He said:Why do you put on the lower garment in this way? He replied: It is how I saw the Messenger of Allah (ﷺ) do it}}
\hadithdefcmd{abudawud}{4097}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ لَعَنَ الْمُتَشَبِّهَاتِ مِنَ النِّسَاءِ بِالرِّجَالِ وَالْمُتَشَبِّهِينَ مِنَ الرِّجَالِ بِالنِّسَاءِ ‏.‏\hadithno{4097}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5885)}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) cursed women who imitate men and men who imitate women}}
\hadithdefcmd{abudawud}{4098}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو عَامِرٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّجُلَ يَلْبَسُ لِبْسَةَ الْمَرْأَةِ وَالْمَرْأَةَ تَلْبَسُ لِبْسَةَ الرَّجُلِ ‏.‏\hadithno{4098}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) cursed the man who dressed like a woman and the woman who dressed like a man}}
\hadithdefcmd{abudawud}{4099}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، لُوَيْنٌ - وَبَعْضُهُ قِرَاءَةً عَلَيْهِ - عَنْ سُفْيَانَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قِيلَ لِعَائِشَةَ رضى الله عنها إِنَّ امْرَأَةً تَلْبَسُ النَّعْلَ ‏.‏ فَقَالَتْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّجُلَةَ مِنَ النِّسَاءِ ‏.‏\hadithno{4099}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn AbuMulaykah told that when someone remarked to Aisha that a woman was wearing sandals, she replied:The Messenger of Allah (ﷺ) cursed mannish women}}
\hadithdefcmd{abudawud}{4100}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّهَا ذَكَرَتْ نِسَاءَ الأَنْصَارِ فَأَثْنَتْ عَلَيْهِنَّ وَقَالَتْ لَهُنَّ مَعْرُوفًا وَقَالَتْ لَمَّا نَزَلَتْ سُورَةُ النُّورِ عَمَدْنَ إِلَى حُجُورٍ - أَوْ حُجُوزٍ شَكَّ أَبُو كَامِلٍ - فَشَقَقْنَهُنَّ فَاتَّخَذْنَهُ خُمُرًا ‏.‏\hadithno{4100}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Safiyyah, daughter of Shaybah, said that Aisha mentioned the women of Ansar, praised them and said good words about them. She then said:When Surat an-Nur came down, they took the curtains, tore them and made head covers (veils) of them}}
\hadithdefcmd{abudawud}{4101}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ لَمَّا نَزَلَتْ ‏\{‏ يُدْنِينَ عَلَيْهِنَّ مِنْ جَلاَبِيبِهِنَّ ‏\}‏ خَرَجَ نِسَاءُ الأَنْصَارِ كَأَنَّ عَلَى رُءُوسِهِنَّ الْغِرْبَانُ مِنَ الأَكْسِيَةِ ‏.‏\hadithno{4101}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: When the verse "That they should cast their outer garments over their persons" was revealed, the women of Ansar came out as if they had crows over their heads by wearing outer garments}}
\hadithdefcmd{abudawud}{4102}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، ح وَحَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، وَابْنُ السَّرْحِ، وَأَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالُوا أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي قُرَّةُ بْنُ عَبْدِ الرَّحْمَنِ الْمَعَافِرِيُّ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ يَرْحَمُ اللَّهُ نِسَاءَ الْمُهَاجِرَاتِ الأُوَلَ لَمَّا أَنْزَلَ اللَّهُ ‏\{‏ وَلْيَضْرِبْنَ بِخُمُرِهِنَّ عَلَى جُيُوبِهِنَّ ‏\}‏ شَقَقْنَ أَكْنَفَ - قَالَ ابْنُ صَالِحٍ أَكْثَفَ - مُرُوطِهِنَّ فَاخْتَمَرْنَ بِهَا ‏.‏\hadithno{4102}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: May Allah have mercy on the early immigrant women. When the verse "That they should draw their veils over their bosoms" was revealed, they tore their thick outer garments and made veils from them}}
\hadithdefcmd{abudawud}{4103}{حَدَّثَنَا ابْنُ السَّرْحِ، قَالَ رَأَيْتُ فِي كِتَابِ خَالِي عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏\hadithno{4103}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn al-Sarh said:I saw (this tradition) in the writing of my maternal uncle from 'Aqil, from Ibn Shihab through a different chain of narrators and to the same effect}}
\hadithdefcmd{abudawud}{4104}{حَدَّثَنَا يَعْقُوبُ بْنُ كَعْبٍ الأَنْطَاكِيُّ، وَمُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، قَالاَ حَدَّثَنَا الْوَلِيدُ، عَنْ سَعِيدِ بْنِ بَشِيرٍ، عَنْ قَتَادَةَ، عَنْ خَالِدٍ، - قَالَ يَعْقُوبُ ابْنُ دُرَيْكٍ - عَنْ عَائِشَةَ، رضى الله عنها أَنَّ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ، دَخَلَتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهَا ثِيَابٌ رِقَاقٌ فَأَعْرَضَ عَنْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ يَا أَسْمَاءُ إِنَّ الْمَرْأَةَ إِذَا بَلَغَتِ الْمَحِيضَ لَمْ تَصْلُحْ أَنْ يُرَى مِنْهَا إِلاَّ هَذَا وَهَذَا ‏"‏ ‏.‏ وَأَشَارَ إِلَى وَجْهِهِ وَكَفَّيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مُرْسَلٌ خَالِدُ بْنُ دُرَيْكٍ لَمْ يُدْرِكْ عَائِشَةَ رضى الله عنها ‏.‏\hadithno{4104}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Asma, daughter of AbuBakr, entered upon the Messenger of Allah (ﷺ) wearing thin clothes. The Messenger of Allah (ﷺ) turned his attention from her. He said: O Asma', when a woman reaches the age of menstruation, it does not suit her that she displays her parts of body except this and this, and he pointed to his face and hands. Abu Dawud said: This is a mursal tradition (i.e. the narrator who transmitted it from 'Aishah is missing) Khalid b. Duraik did not see 'Aishah}}
\hadithdefcmd{abudawud}{4105}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، مَوْهَبٍ قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ أُمَّ سَلَمَةَ، اسْتَأْذَنَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْحِجَامَةِ فَأَمَرَ أَبَا طَيْبَةَ أَنْ يَحْجُمَهَا ‏.‏ قَالَ حَسِبْتُ أَنَّهُ قَالَ كَانَ أَخَاهَا مِنَ الرَّضَاعَةِ أَوْ غُلاَمًا لَمْ يَحْتَلِمْ ‏.‏\hadithno{4105}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2206)}\hadithtrans{Narrated Jabir:Umm Salamah asked the Messenger of Allah (ﷺ) permission for getting herself cupped. He commanded Abu Tibah to cup her. The transmitter said: I think he was her foster-brother or a boy not yet of age}}
\hadithdefcmd{abudawud}{4106}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَبُو جُمَيْعٍ، سَالِمُ بْنُ دِينَارٍ عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَى فَاطِمَةَ بِعَبْدٍ قَدْ وَهَبَهُ لَهَا قَالَ وَعَلَى فَاطِمَةَ رَضِيَ اللَّهُ عَنْهَا ثَوْبٌ إِذَا قَنَّعَتْ بِهِ رَأْسَهَا لَمْ يَبْلُغْ رِجْلَيْهَا وَإِذَا غَطَّتْ بِهِ رِجْلَيْهَا لَمْ يَبْلُغْ رَأْسَهَا فَلَمَّا رَأَى النَّبِيُّ صلى الله عليه وسلم مَا تَلْقَى قَالَ ‏ "‏ إِنَّهُ لَيْسَ عَلَيْكِ بَأْسٌ إِنَّمَا هُوَ أَبُوكِ وَغُلاَمُكِ ‏"‏ ‏.‏\hadithno{4106}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) brought Fatimah a slave which he donated to her. Fatimah wore a garment which, when she covered her head, did not reach her feet, and when she covered her feet by it, that garment did not reach her head. When the Prophet (ﷺ) saw her struggle, he said: There is no harm to you: Here is only your father and slave}}
\hadithdefcmd{abudawud}{4107}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، وَهِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ يَدْخُلُ عَلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم مُخَنَّثٌ فَكَانُوا يَعُدُّونَهُ مِنْ غَيْرِ أُولِي الإِرْبَةِ فَدَخَلَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم يَوْمًا وَهُوَ عِنْدَ بَعْضِ نِسَائِهِ وَهُوَ يَنْعَتُ امْرَأَةً فَقَالَ إِنَّهَا إِذَا أَقْبَلَتْ أَقْبَلَتْ بِأَرْبَعٍ وَإِذَا أَدْبَرَتْ أَدْبَرَتْ بِثَمَانٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَ أَرَى هَذَا يَعْلَمُ مَا هَا هُنَا لاَ يَدْخُلَنَّ عَلَيْكُنَّ هَذَا ‏"‏ ‏.‏ فَحَجَبُوهُ ‏.‏\hadithno{4107}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2181)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A mukhannath (eunuch) used to enter upon the wives of Prophet (ﷺ). They (the people) counted him among those who were free of physical needs. One day the Prophet (ﷺ) entered upon us when he was with one of his wives, and was describing the qualities of a woman, saying: When she comes forward, she comes forward with four (folds in her stomach), and when she goes backward, she goes backward with eight (folds in her stomach). The Prophet (ﷺ) said: Do I not see that this (man) knows what here lies. Then they (the wives) observed veil from him}}
\hadithdefcmd{abudawud}{4108}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، بِمَعْنَاهُ ‏.‏\hadithno{4108}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2181)}\hadithtrans{The tradition mentioned above has also been transmitted by 'Aishah through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4109}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، بِهَذَا الْحَدِيثِ زَادَ وَأَخْرَجَهُ فَكَانَ بِالْبَيْدَاءِ يَدْخُلُ كُلَّ جُمُعَةٍ يَسْتَطْعِمُ ‏.‏\hadithno{4109}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned about has also been transmitted by 'Aishah through a different chain of narrators. This version has:He (the Prophet) exiled him and he lived in a desert (outside Medina). He would come every Friday asking for food}}
\hadithdefcmd{abudawud}{4110}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا عُمَرُ، عَنِ الأَوْزَاعِيِّ، فِي هَذِهِ الْقِصَّةِ فَقِيلَ يَا رَسُولَ اللَّهِ إِنَّهُ إِذًا يَمُوتُ مِنَ الْجُوعِ فَأَذِنَ لَهُ أَنْ يَدْخُلَ فِي كُلِّ جُمُعَةٍ مَرَّتَيْنِ فَيَسْأَلَ ثُمَّ يَرْجِعَ ‏.‏\hadithno{4110}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by al-Auza'i through a different chain of narrators. This version adds:He was told: Messenger of Allah, in that case he will of starvation. So he allowed him to visit (the cit) twice a week so that he might ask for food and go back}}
\hadithdefcmd{abudawud}{4111}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ وَقُلْ لِلْمُؤْمِنَاتِ يَغْضُضْنَ مِنْ أَبْصَارِهِنَّ ‏\}‏ الآيَةَ فَنُسِخَ وَاسْتُثْنِيَ مِنْ ذَلِكَ ‏\{‏ وَالْقَوَاعِدُ مِنَ النِّسَاءِ اللاَّتِي لاَ يَرْجُونَ نِكَاحًا ‏\}‏ الآيَةَ ‏.‏\hadithno{4111}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:The verse: "And say to the believing women that they should lower gaze was partly abrogated by the verse: "Such elderly women as are past the prospect of marriage}}
\hadithdefcmd{abudawud}{4112}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي نَبْهَانُ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، قَالَتْ كُنْتُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ مَيْمُونَةُ فَأَقْبَلَ ابْنُ أُمِّ مَكْتُومٍ وَذَلِكَ بَعْدَ أَنْ أُمِرْنَا بِالْحِجَابِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ احْتَجِبَا مِنْهُ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ أَلَيْسَ أَعْمَى لاَ يُبْصِرُنَا وَلاَ يَعْرِفُنَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَفَعَمْيَاوَانِ أَنْتُمَا أَلَسْتُمَا تُبْصِرَانِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لأَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم خَاصَّةً أَلاَ تَرَى إِلَى اعْتِدَادِ فَاطِمَةَ بِنْتِ قَيْسٍ عِنْدَ ابْنِ أُمِّ مَكْتُومٍ قَدْ قَالَ النَّبِيُّ صلى الله عليه وسلم لِفَاطِمَةَ بِنْتِ قَيْسٍ ‏"‏ اعْتَدِّي عِنْدَ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ رَجُلٌ أَعْمَى تَضَعِينَ ثِيَابَكِ عِنْدَهُ ‏"‏ ‏.‏\hadithno{4112}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: I was with the Messenger of Allah (ﷺ) while Maymunah was with him. Then Ibn Umm Maktum came. This happened when we were ordered to observe veil (purdah). The Prophet (ﷺ) said: Observe veil from him. We asked: Messenger of Allah! is he not blind? He can neither see us nor recognise us. The Prophet (ﷺ) said: Are both of you blind? Do you not see him? AbuDawud said: This was peculiar to the wives of the Prophet (ﷺ). Do you not see that Fatimah daughter of Qays passed her waiting period with Ibn Umm Maktum. The Prophet (ﷺ) said to Fatimah daughter of Qays: Pass your waiting period with Ibn Umm Maktum, for he is a blind man. You can put off your clothes with him}}
\hadithdefcmd{abudawud}{4113}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمَيْمُونِ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا زَوَّجَ أَحَدُكُمْ عَبْدَهُ أَمَتَهُ فَلاَ يَنْظُرْ إِلَى عَوْرَتِهَا ‏"‏ ‏.‏\hadithno{4113}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Prophet (ﷺ) said: When one of you marries his male-slave to his slave-woman, he should not look at her private parts}}
\hadithdefcmd{abudawud}{4114}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنِي دَاوُدُ بْنُ سَوَّارٍ الْمُزَنِيُّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا زَوَّجَ أَحَدُكُمْ خَادِمَهُ عَبْدَهُ أَوْ أَجِيرَهُ فَلاَ يَنْظُرْ إِلَى مَا دُونَ السُّرَّةِ وَفَوْقَ الرُّكْبَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ صَوَابُهُ سَوَّارُ بْنُ دَاوُدَ الْمُزَنِيُّ الصَّيْرَفِيُّ وَهِمَ فِيهِ وَكِيعٌ ‏.‏\hadithno{4114}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Prophet (ﷺ) said: When one of you marries his female servant to his slave or to his employee, he should not look at her private part below the navel and above the knees. Abu Dawud said: The correct name is Sawwad b. Dawud al-Muzani al-Sairafi (and not Dawud b. Sawwad as mentioned in the chain). The narrator waki' misunderstood it}}
\hadithdefcmd{abudawud}{4115}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ وَهْبٍ، مَوْلَى أَبِي أَحْمَدَ عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا وَهِيَ تَخْتَمِرُ فَقَالَ ‏"‏ لَيَّةً لاَ لَيَّتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ مَعْنَى قَوْلِهِ ‏"‏ لَيَّةً لاَ لَيَّتَيْنِ ‏"‏ ‏.‏ يَقُولُ لاَ تَعْتَمَّ مِثْلَ الرَّجُلِ لاَ تُكَرِّرْهُ طَاقًا أَوْ طَاقَيْنِ ‏.‏\hadithno{4115}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Prophet (ﷺ) came to visit her when she was veiled, and said: use one fold and not two. Abu Dawud said: "Use one fold and not two" means: "Do not fold it like the turban of a man. Do not double it up manifolds}}
\hadithdefcmd{abudawud}{4116}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَأَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا ابْنُ لَهِيعَةَ، عَنْ مُوسَى بْنِ جُبَيْرٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبَّاسٍ، حَدَّثَهُ عَنْ خَالِدِ بْنِ يَزِيدَ بْنِ مُعَاوِيَةَ، عَنْ دِحْيَةَ بْنِ خَلِيفَةَ الْكَلْبِيِّ، أَنَّهُ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَبَاطِيَّ فَأَعْطَانِي مِنْهَا قُبْطِيَّةً فَقَالَ ‏"‏ اصْدَعْهَا صَدْعَيْنِ فَاقْطَعْ أَحَدَهُمَا قَمِيصًا وَأَعْطِ الآخَرَ امْرَأَتَكَ تَخْتَمِرُ بِهِ ‏"‏ ‏.‏ فَلَمَّا أَدْبَرَ قَالَ ‏"‏ وَأْمُرِ امْرَأَتَكَ أَنْ تَجْعَلَ تَحْتَهُ ثَوْبًا لاَ يَصِفُهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ يَحْيَى بْنُ أَيُّوبَ فَقَالَ عَبَّاسُ بْنُ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ ‏.‏\hadithno{4116}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Dihyah ibn Khalifah al-Kalbi: The Messenger of Allah (ﷺ) was brought some pieces of fine Egyptian linen and he gave me one and said: Divide it into two; cut one of the pieces into a shirt and give the other to your wife for veil. Then when he turned away, he said: And order your wife to wear a garment below it and not show her figure. Abu Dawud said: Yahya b. Ayyub transmitted it and said: 'Abbas b. 'Ubaid Allah b. 'Abbas}}
\hadithdefcmd{abudawud}{4117}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، أَنَّهَا أَخْبَرَتْهُ أَنَّ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ ذَكَرَ الإِزَارَ فَالْمَرْأَةُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ تُرْخِي شِبْرًا ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ إِذًا يَنْكَشِفُ عَنْهَا ‏.‏ قَالَ ‏"‏ فَذِرَاعًا لاَ تَزِيدُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4117}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Safiyyah, daughter of AbuUbayd, said:When the Messenger of Allah (ﷺ) mentioned lower garment, Umm Salamah, wife of the Messenger of Allah (ﷺ), asked him: And a woman, Messenger of Allah? He replied: She may hang down a span. Umm Salamah said: Still it (foot) will be uncovered. He said: Then a forearm's length, nor exceeding it}}
\hadithdefcmd{abudawud}{4118}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ إِسْحَاقَ وَأَيُّوبُ بْنُ مُوسَى عَنْ نَافِعٍ عَنْ صَفِيَّةَ ‏.‏\hadithno{4118}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Umm Salamah from the Prophet (ﷺ) through a different chain of narrators. Abu Dawud said:Ibn Ishaq and Ayyub b. Musa transmitted it from Nafi' from Safiyyah}}
\hadithdefcmd{abudawud}{4119}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، أَخْبَرَنِي زَيْدٌ الْعَمِّيُّ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأُمَّهَاتِ الْمُؤْمِنِينَ فِي الذَّيْلِ شِبْرًا ثُمَّ اسْتَزَدْنَهُ فَزَادَهُنَّ شِبْرًا فَكُنَّ يُرْسِلْنَ إِلَيْنَا فَنَذْرَعُ لَهُنَّ ذِرَاعًا ‏.‏\hadithno{4119}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) gave licence to the Mothers of the believers (i.e. the wives of the Prophet) to hang down their lower garment a span. Then they asked him to increase it, and he increased one span for them. They would send (the garment) to us and we would measure it one forearm's length for them}}
\hadithdefcmd{abudawud}{4120}{حَدَّثَنَا مُسَدَّدٌ، وَوَهْبُ بْنُ بَيَانٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي خَلَفٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، - قَالَ مُسَدَّدٌ وَوَهْبٌ - عَنْ مَيْمُونَةَ، قَالَتْ أُهْدِيَ لِمَوْلاَةٍ لَنَا شَاةٌ مِنَ الصَّدَقَةِ فَمَاتَتْ فَمَرَّ بِهَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلاَ دَبَغْتُمْ إِهَابَهَا فَاسْتَمْتَعْتُمْ بِهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا مَيْتَةٌ ‏.‏ قَالَ ‏"‏ إِنَّمَا حُرِّمَ أَكْلُهَا ‏"‏ ‏.‏\hadithno{4120}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1492) Sahih Muslim (363)}\hadithtrans{Ibn 'Abbas said - (Musaddad and Wahb transmitted from Maimunah) Maimunah said:A sheep was given in alms to a female client of ours, but it died. The Prophet (ﷺ) passed it and said: Why did you not tan its skin and get some good out of it ? They replied: Messenger of Allah, it died a natural death. He said: It is only the eating of it that is prohibited}}
\hadithdefcmd{abudawud}{4121}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الْحَدِيثِ لَمْ يَذْكُرْ مَيْمُونَةَ قَالَ فَقَالَ ‏ "‏ أَلاَ انْتَفَعْتُمْ بِإِهَابِهَا ‏"‏ ‏.‏ ثُمَّ ذَكَرَ مَعْنَاهُ لَمْ يَذْكُرِ الدِّبَاغَ ‏.‏\hadithno{4121}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1492) Sahih Muslim (363)}\hadithtrans{The tradition mentioned above has also been transmitted by al-Zuhri who did not mention Maimunah. This version has:He said: Why did you not make use of it ? He then mentioned the rest of the tradition to the same effect but did not mention tanning}}
\hadithdefcmd{abudawud}{4122}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ قَالَ مَعْمَرٌ وَكَانَ الزُّهْرِيُّ يُنْكِرُ الدِّبَاغَ وَيَقُولُ يُسْتَمْتَعُ بِهِ عَلَى كُلِّ حَالٍ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَذْكُرِ الأَوْزَاعِيُّ وَيُونُسُ وَعُقَيْلٌ فِي حَدِيثِ الزُّهْرِيِّ الدِّبَاغَ وَذَكَرَهُ الزُّبَيْدِيُّ وَسَعِيدُ بْنُ عَبْدِ الْعَزِيزِ وَحَفْصُ بْنُ الْوَلِيدِ ذَكَرُوا الدِّبَاغَ ‏.‏\hadithno{4122}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Ma'mar said:Al-Zuhri used to deny tanning and say: Some good can be got out of it in any condition Abu Dawud said: Al-Auza'i, Yunus and 'Uqail did not mention tanning. al-Zubaidi, Sa'id b. 'Abd al-Aziz and Hafs b. 'Abd al-'Aziz mentioned tanning}}
\hadithdefcmd{abudawud}{4123}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ وَعْلَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا دُبِغَ الإِهَابُ فَقَدْ طَهُرَ ‏"‏ ‏.‏\hadithno{4123}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (366)}\hadithtrans{Narrated Ibn 'Abbas:That he heard the Messenger of Allah (ﷺ) say: When a skin is tanned, it is pure}}
\hadithdefcmd{abudawud}{4124}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَنْ يُسْتَمْتَعَ بِجُلُودِ الْمَيْتَةِ إِذَا دُبِغَتْ ‏.‏\hadithno{4124}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) ordered that the skins of the animals which had died a natural death should be used when they are tanned}}
\hadithdefcmd{abudawud}{4125}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ جَوْنِ بْنِ قَتَادَةَ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ أَتَى عَلَى بَيْتٍ فَإِذَا قِرْبَةٌ مُعَلَّقَةٌ فَسَأَلَ الْمَاءَ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ ‏ "‏ دِبَاغُهَا طُهُورُهَا ‏"‏ ‏.‏\hadithno{4125}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salamah ibn al-Muhabbaq: On the expedition of Tabuk the Messenger of Allah (ﷺ) came to a household and, seeing a bucket hanging, asked for water. They said: Messenger of Allah, the animal died a natural death. He replied; Its tanning is its purification}}
\hadithdefcmd{abudawud}{4126}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - يَعْنِي ابْنَ الْحَارِثِ - عَنْ كَثِيرِ بْنِ فَرْقَدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكِ بْنِ حُذَافَةَ، حَدَّثَهُ عَنْ أُمِّهِ الْعَالِيَةِ بِنْتِ سُبَيْعٍ، أَنَّهَا قَالَتْ كَانَ لِي غَنَمٌ بِأُحُدٍ فَوَقَعَ فِيهَا الْمَوْتُ فَدَخَلْتُ عَلَى مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهَا فَقَالَتْ لِي مَيْمُونَةُ لَوْ أَخَذْتِ جُلُودَهَا فَانْتَفَعْتِ بِهَا ‏.‏ فَقَالَتْ أَوَيَحِلُّ ذَلِكَ قَالَتْ نَعَمْ ‏.‏ مَرَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم رِجَالٌ مِنْ قُرَيْشٍ يَجُرُّونَ شَاةً لَهُمْ مِثْلَ الْحِمَارِ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ أَخَذْتُمْ إِهَابَهَا ‏"‏ ‏.‏ قَالُوا إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُطَهِّرُهَا الْمَاءُ وَالْقَرَظُ ‏"‏ ‏.‏\hadithno{4126}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Aliyah, daughter of Subay', said:I had some sheep at Uhud, and they began to die. I then entered upon Maymunah, wife of the Prophet (ﷺ), and mentioned it to her. Maymunah said to me: If you took their skins and made use of them, (that would be better for you). She asked: Is that lawful? She replied, Yes. Some people of the Quraysh passed by the Messenger of Allah (ﷺ) dragging a sheep of theirs as big as an ass. The Messenger of Allah (ﷺ) said to them: Would that you took its skin. They said: It died a natural death. The Messenger of Allah (ﷺ) said: Water and leaves of the mimosa flava purify it}}
\hadithdefcmd{abudawud}{4127}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ قُرِئَ عَلَيْنَا كِتَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِأَرْضِ جُهَيْنَةَ وَأَنَا غُلاَمٌ شَابٌّ ‏ "‏ أَنْ لاَ تَسْتَمْتِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏"‏ ‏.‏\hadithno{4127}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Ukaym: The letter of the Messenger of Allah (ﷺ) was read out to us in the territory of Juhaynah when I was a young boy: Do not make use of the skin or sinew of an animal which died a natural death}}
\hadithdefcmd{abudawud}{4128}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، مَوْلَى بَنِي هَاشِمٍ حَدَّثَنَا الثَّقَفِيُّ، عَنْ خَالِدٍ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، أَنَّهُ انْطَلَقَ هُوَ وَنَاسٌ مَعَهُ إِلَى عَبْدِ اللَّهِ بْنِ عُكَيْمٍ - رَجُلٍ مِنْ جُهَيْنَةَ - قَالَ الْحَكَمُ فَدَخَلُوا وَقَعَدْتُ عَلَى الْبَابِ فَخَرَجُوا إِلَىَّ فَأَخْبَرُونِي أَنَّ عَبْدَ اللَّهِ بْنَ عُكَيْمٍ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَى جُهَيْنَةَ قَبْلَ مَوْتِهِ بِشَهْرٍ أَنْ لاَ يَنْتَفِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏.‏ قَالَ أَبُو دَاوُدَ فَإِذَا دُبِغَ لاَ يُقَالُ لَهُ إِهَابٌ إِنَّمَا يُسَمَّى شَنًّا وَقِرْبَةً قَالَ النَّضْرُ بْنُ شُمَيْلٍ يُسَمَّى إِهَابًا مَا لَمْ يُدْبَغْ ‏.‏\hadithno{4128}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Hakam ibn Uyaynah said that he went along with some people to Abdullah ibn Ukaym, a man of Juhaynah. al-Hakam said:They entered and I sat at the door. Then they came out and told me that Abdullah ibn Ukaym had informed them that the Messenger of Allah (ﷺ) had written to Juhaynah one month before his death: Do not make use of the skin or sinew of an animal which died a natural death. Abu Dawud said: Al-Nadr b. Shumail said: The skin is called ihab when it is not tanned and when it is tanned, it not called ihab but na,es shann and qirbah (tanned skin or leather)}}
\hadithdefcmd{abudawud}{4129}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ أَبِي الْمُعْتَمِرِ، عَنِ ابْنِ سِيرِينَ، عَنْ مُعَاوِيَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَرْكَبُوا الْخَزَّ وَلاَ النِّمَارَ ‏"‏ ‏.‏ قَالَ وَكَانَ مُعَاوِيَةُ لاَ يُتَّهَمُ فِي الْحَدِيثِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ لَنَا أَبُو سَعِيدٍ قَالَ لَنَا أَبُو دَاوُدَ أَبُو الْمُعْتَمِرِ اسْمُهُ يَزِيدُ بْنُ طَهْمَانَ كَانَ يَنْزِلُ الْحِيرَةَ ‏.‏\hadithno{4129}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'awiyah: The Prophet (ﷺ) said: Do not ride on silk stuff and panther skins. AbuSa'id said to us: AbuDawud said to us: The name of AbulMu'tamir is Yazid ibn Tahman. He lived in al-Hirah}}
\hadithdefcmd{abudawud}{4130}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عِمْرَانُ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا جِلْدُ نَمِرٍ ‏"‏ ‏.‏\hadithno{4130}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: The angels do not accompany those fellow travellers who have panther skin}}
\hadithdefcmd{abudawud}{4131}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، قَالَ وَفَدَ الْمِقْدَامُ بْنُ مَعْدِيكَرِبَ وَعَمْرُو بْنُ الأَسْوَدِ وَرَجُلٌ مِنْ بَنِي أَسَدٍ مِنْ أَهْلِ قِنَّسْرِينَ إِلَى مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ فَقَالَ مُعَاوِيَةُ لِلْمِقْدَامِ أَعَلِمْتَ أَنَّ الْحَسَنَ بْنَ عَلِيٍّ تُوُفِّيَ فَرَجَّعَ الْمِقْدَامُ فَقَالَ لَهُ رَجُلٌ أَتَرَاهَا مُصِيبَةً قَالَ لَهُ وَلِمَ لاَ أَرَاهَا مُصِيبَةً وَقَدْ وَضَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حِجْرِهِ فَقَالَ ‏ "‏ هَذَا مِنِّي وَحُسَيْنٌ مِنْ عَلِيٍّ ‏"‏ ‏.‏ فَقَالَ الأَسَدِيُّ جَمْرَةٌ أَطْفَأَهَا اللَّهُ عَزَّ وَجَلَّ ‏.‏ قَالَ فَقَالَ الْمِقْدَامُ أَمَّا أَنَا فَلاَ أَبْرَحُ الْيَوْمَ حَتَّى أُغِيظَكَ وَأُسْمِعَكَ مَا تَكْرَهُ ‏.‏ ثُمَّ قَالَ يَا مُعَاوِيَةُ إِنْ أَنَا صَدَقْتُ فَصَدِّقْنِي وَإِنْ أَنَا كَذَبْتُ فَكَذِّبْنِي قَالَ أَفْعَلُ ‏.‏ قَالَ فَأَنْشُدُكَ بِاللَّهِ هَلْ تَعْلَمُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الذَّهَبِ قَالَ نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكَ بِاللَّهِ هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ لُبْسِ الْحَرِيرِ قَالَ نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكَ بِاللَّهِ هَلْ تَعْلَمُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ جُلُودِ السِّبَاعِ وَالرُّكُوبِ عَلَيْهَا قَالَ نَعَمْ ‏.‏ قَالَ فَوَاللَّهِ لَقَدْ رَأَيْتُ هَذَا كُلَّهُ فِي بَيْتِكَ يَا مُعَاوِيَةُ ‏.‏ فَقَالَ مُعَاوِيَةُ قَدْ عَلِمْتُ أَنِّي لَنْ أَنْجُوَ مِنْكَ يَا مِقْدَامُ قَالَ خَالِدٌ فَأَمَرَ لَهُ مُعَاوِيَةُ بِمَا لَمْ يَأْمُرْ لِصَاحِبَيْهِ وَفَرَضَ لاِبْنِهِ فِي الْمِائَتَيْنِ فَفَرَّقَهَا الْمِقْدَامُ فِي أَصْحَابِهِ قَالَ وَلَمْ يُعْطِ الأَسَدِيُّ أَحَدًا شَيْئًا مِمَّا أَخَذَ فَبَلَغَ ذَلِكَ مُعَاوِيَةَ فَقَالَ أَمَّا الْمِقْدَامُ فَرَجُلٌ كَرِيمٌ بَسَطَ يَدَهُ وَأَمَّا الأَسَدِيُّ فَرَجُلٌ حَسَنُ الإِمْسَاكِ لِشَيْئِهِ ‏.‏\hadithno{4131}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Khalid said:Al-Miqdam ibn Ma'dikarib and a man of Banu Asad from the people of Qinnisrin went to Mu'awiyah ibn AbuSufyan. Mu'awiyah said to al-Miqdam: Do you know that al-Hasan ibn Ali has died? Al-Miqdam recited the Qur'anic verse "We belong to Allah and to Him we shall return." A man asked him: Do you think it a calamity? He replied: Why should I not consider it a calamity when it is a fact that the Messenger of Allah (ﷺ) used to take him on his lap, saying: This belongs to me and Husayn belongs to Ali? The man of Banu Asad said: (He was) a live coal which Allah has extinguished. Al-Miqdam said: Today I shall continue to make you angry and make you hear what you dislike. He then said: Mu'awiyah, if I speak the truth, declare me true, and if I tell a lie, declare me false. He said: Do so. He said: I adjure you by Allah, did you hear the Messenger of Allah (ﷺ) forbidding use to wear gold? He replied: Yes. He said: I adjure you by Allah, do you know that the Messenger of Allah (ﷺ) prohibited the wearing of silk? He replied: Yes. He said: I adjure you by Allah, do you know that the Messenger of Allah (ﷺ) prohibited the wearing of the skins of beasts of prey and riding on them? He said: Yes. He said: I swear by Allah, I saw all this in your house, O Mu'awiyah. Mu'awiyah said: I know that I cannot be saved from you, O Miqdam. Khalid said: Mu'awiyah then ordered to give him what he did not order to give to his two companions, and gave a stipend of two hundred (dirhams) to his son. Al-Miqdam then divided it among his companions, and the man of Banu Asad did not give anything to anyone from the property he received. When Mu'awiyah was informed about it, he said: Al-Miqdam is a generous man; he has an open hand (for generosity). The man of Banu Asad withholds his things in a good manner}}
\hadithdefcmd{abudawud}{4132}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، أَنَّ يَحْيَى بْنَ سَعِيدٍ، وَإِسْمَاعِيلَ بْنَ إِبْرَاهِيمَ، حَدَّثَاهُمُ - الْمَعْنَى، - عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ بْنِ أُسَامَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ جُلُودِ السِّبَاعِ ‏.‏\hadithno{4132}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu al-Malih b. Usamah quoting his father said:The Messenger of Allah (ﷺ) forbade (the use of) the skins of beasts of prey}}
\hadithdefcmd{abudawud}{4133}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَقَالَ ‏ "‏ أَكْثِرُوا مِنَ النِّعَالِ فَإِنَّ الرَّجُلَ لاَ يَزَالُ رَاكِبًا مَا انْتَعَلَ ‏"‏ ‏.‏\hadithno{4133}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2096)}\hadithtrans{Narrated Jabir:We were with the Prophet (ﷺ) on a journey. He said: Make a general practice of wearing sandals, for a man keeps riding as long as he wears sandals}}
\hadithdefcmd{abudawud}{4134}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَعْلَ النَّبِيِّ، صلى الله عليه وسلم كَانَ لَهَا قِبَالاَنِ ‏.‏\hadithno{4134}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5857)}\hadithtrans{Narrated Anas:The sandals of the Prophet (ﷺ) had two thongs}}
\hadithdefcmd{abudawud}{4135}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ أَبُو يَحْيَى، أَخْبَرَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَنْتَعِلَ الرَّجُلُ قَائِمًا ‏.‏\hadithno{4135}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) forbade that a man should put on sandals while standing}}
\hadithdefcmd{abudawud}{4136}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْشِي أَحَدُكُمْ فِي النَّعْلِ الْوَاحِدَةِ لِيَنْتَعِلْهُمَا جَمِيعًا أَوْ لِيَخْلَعْهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{4136}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5855) Sahih Muslim (2097)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: None of you should walk with one sandal, but should wear a pair or should put off both of them}}
\hadithdefcmd{abudawud}{4137}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا انْقَطَعَ شِسْعُ أَحَدِكُمْ فَلاَ يَمْشِ فِي نَعْلٍ وَاحِدَةٍ حَتَّى يُصْلِحَ شِسْعَهُ وَلاَ يَمْشِ فِي خُفٍّ وَاحِدٍ وَلاَ يَأْكُلْ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{4137}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2099)}\hadithtrans{Narrated Jabir:The Messenger of Allah (ﷺ) as saying: When the thong (of a sandal) of one of you is cut off, he should not walk with one sandal till he repairs his thongs. He should not walk with one shoe, or eat with his left hand}}
\hadithdefcmd{abudawud}{4138}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ هَارُونَ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ أَبِي نَهِيكٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مِنَ السُّنَّةِ إِذَا جَلَسَ الرَّجُلُ أَنْ يَخْلَعَ نَعْلَيْهِ فَيَضَعَهُمَا بِجَنْبِهِ ‏.‏\hadithno{4138}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: It is part of the Sunnah that when a man sits down, he should take off his sandals and place them at his side}}
\hadithdefcmd{abudawud}{4139}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَعَلَ أَحَدُكُمْ فَلْيَبْدَأْ بِالْيَمِينِ وَإِذَا نَزَعَ فَلْيَبْدَأْ بِالشِّمَالِ لِتَكُنِ الْيَمِينُ أَوَّلَهُمَا يَنْتَعِلُ وَآخِرَهُمَا يَنْزِعُ ‏"‏ ‏.‏\hadithno{4139}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5856) Sahih Muslim (2097)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: When one of you puts on sandals, he should put on his right one first, and when he takes them off, he should take off the left one first ; so that the right one should be the first to be put on and the last to be taken off}}
\hadithdefcmd{abudawud}{4140}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ بْنِ سُلَيْمٍ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ التَّيَمُّنَ مَا اسْتَطَاعَ فِي شَأْنِهِ كُلِّهِ فِي طُهُورِهِ وَتَرَجُّلِهِ وَنَعْلِهِ ‏.‏ قَالَ مُسْلِمٌ وَسِوَاكِهِ وَلَمْ يَذْكُرْ فِي شَأْنِهِ كُلِّهِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَنْ شُعْبَةَ مُعَاذٌ وَلَمْ يَذْكُرْ سِوَاكَهُ ‏.‏\hadithno{4140}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (168) Sahih Muslim (268)}\hadithtrans{Narrated 'Aishah: The Messenger of Allah (ﷺ) liked to begin with the right side as far as possible in all conditions: in his purification, and combing. The narrator Muslim added: "in using tooth-stick," and he did not mention "in all his conditions". Abu Dawud said: Shu'bah transmitted it from Mu'adh, but did not mention "his tooth-stick}}
\hadithdefcmd{abudawud}{4141}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا لَبِسْتُمْ وَإِذَا تَوَضَّأْتُمْ فَابْدَءُوا بِأَيَامِنِكُمْ ‏"‏ ‏.‏\hadithno{4141}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When you put on (a garment) and when you perform ablution, you should begin with your right side}}
\hadithdefcmd{abudawud}{4142}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الْهَمْدَانِيُّ الرَّمْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ أَبِي هَانِئٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْفُرُشَ فَقَالَ ‏ "‏ فِرَاشٌ لِلرَّجُلِ وَفِرَاشٌ لِلْمَرْأَةِ وَفِرَاشٌ لِلضَّيْفِ وَالرَّابِعُ لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{4142}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2084)}\hadithtrans{Narrated Jabir bin ‘Abdullah :The Messenger of Allah (ﷺ) mentioned bedding and said: There should be bedding for a man, bedding for his wife, and third for a guest, but a fourth for the devil}}
\hadithdefcmd{abudawud}{4143}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، عَنْ وَكِيعٍ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فِي بَيْتِهِ فَرَأَيْتُهُ مُتَّكِئًا عَلَى وِسَادَةٍ - زَادَ ابْنُ الْجَرَّاحِ - عَلَى يَسَارِهِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ إِسْحَاقُ بْنُ مَنْصُورٍ عَنْ إِسْرَائِيلَ أَيْضًا عَلَى يَسَارِهِ ‏.‏\hadithno{4143}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Samurah: When I came to the Prophet (ﷺ) in his house, I saw him sitting reclining on a pillow. The narrator Ibn al-Jarrah added: "on his left side". Abu Dawud said: Ishaq b. Mansur transmitted it from Isra'il, also mentioning the words "on his left side}}
\hadithdefcmd{abudawud}{4144}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ إِسْحَاقَ بْنِ سَعِيدِ بْنِ عَمْرٍو الْقُرَشِيِّ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّهُ رَأَى رُفْقَةً مِنْ أَهْلِ الْيَمَنِ رِحَالُهُمُ الأَدَمُ فَقَالَ مَنْ أَحَبَّ أَنْ يَنْظُرَ إِلَى أَشْبَهِ رُفْقَةٍ كَانُوا بِأَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَلْيَنْظُرْ إِلَى هَؤُلاَءِ ‏.‏\hadithno{4144}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sa'id ibn Amr al-Qurashi quoting his father said:Ibn Umar (once) saw some fellow travellers of the Yemen. They had their saddles (on camels) of leather. He said: If anyone likes to see the fellow travellers most resembling to the Companions of the Messenger of Allah (ﷺ), he should see them}}
\hadithdefcmd{abudawud}{4145}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَّخَذْتُمْ أَنْمَاطًا ‏"‏ ‏.‏ قُلْتُ وَأَنَّى لَنَا الأَنْمَاطُ قَالَ ‏"‏ أَمَا إِنَّهَا سَتَكُونُ لَكُمْ أَنْمَاطٌ ‏"‏ ‏.‏\hadithno{4145}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5161) Sahih Muslim (2083)}\hadithtrans{Narrated Jabir:The Messenger of Allah (ﷺ) said to me: Have you made cushions ? I said: How can we afford cushions ? He said: Soon you will have cushions}}
\hadithdefcmd{abudawud}{4146}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَأَحْمَدُ بْنُ مَنِيعٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ وِسَادَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ ابْنُ مَنِيعٍ - الَّتِي يَنَامُ عَلَيْهَا بِاللَّيْلِ - ثُمَّ اتَّفَقَا - مِنْ أَدَمٍ حَشْوُهَا لِيفٌ ‏.‏\hadithno{4146}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2082)}\hadithtrans{Narrated 'Aishah:The pillow of the Messenger of Allah (ﷺ) on which he slept at night (according to the version on Ibn Mani') was of leather stuffed with palm fibre (according to the agreed version)}}
\hadithdefcmd{abudawud}{4147}{حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ حَيَّانَ - عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَتْ ضِجْعَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَدَمٍ حَشْوُهَا لِيفٌ ‏.‏\hadithno{4147}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2082)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The bedding of the Messenger of Allah (ﷺ) consisted of leather stuffed with palm fibre}}
\hadithdefcmd{abudawud}{4148}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ فِرَاشُهَا حِيَالَ مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4148}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Her bedding was in front of the place of prayer of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4149}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى فَاطِمَةَ رضى الله عنها فَوَجَدَ عَلَى بَابِهَا سِتْرًا فَلَمْ يَدْخُلْ قَالَ وَقَلَّمَا كَانَ يَدْخُلُ إِلاَّ بَدَأَ بِهَا فَجَاءَ عَلِيٌّ رَضِيَ اللَّهُ عَنْهُ فَرَآهَا مُهْتَمَّةً فَقَالَ مَا لَكِ قَالَتْ جَاءَ النَّبِيُّ صلى الله عليه وسلم إِلَىَّ فَلَمْ يَدْخُلْ فَأَتَاهُ عَلِيٌّ رضى الله عنه فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ فَاطِمَةَ اشْتَدَّ عَلَيْهَا أَنَّكَ جِئْتَهَا فَلَمْ تَدْخُلْ عَلَيْهَا ‏.‏ قَالَ ‏"‏ وَمَا أَنَا وَالدُّنْيَا وَمَا أَنَا وَالرَّقْمَ ‏"‏ ‏.‏ فَذَهَبَ إِلَى فَاطِمَةَ فَأَخْبَرَهَا بِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ قُلْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَا يَأْمُرُنِي بِهِ ‏.‏ قَالَ ‏"‏ قُلْ لَهَا فَلْتُرْسِلْ بِهِ إِلَى بَنِي فُلاَنٍ ‏"‏ ‏.‏\hadithno{4149}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2613)}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) came to Fatimah and found a curtain hanging at her door, so he did not enter. Whenever he entered (the house), he would visit her first. Then Ali came and found that Fatimah was grieved. He asked: What is the matter with you? She replied: The Messenger of Allah (ﷺ) came to me but did not enter (the house). Ali then came to him and said: Messenger of Allah, Fatimah felt it keenly that you came to visit her but did not go in. He replied: What have I to do with this world? What have I to do with prints and figures (on the curtain)? He (Ali) then went to Fatimah and informed her of what the Messenger of Allah (ﷺ) had said. She said: Ask the Messenger of Allah (ﷺ) what he me to do about it. He (the Prophet) said: Tell her that she must send it to so-and-so}}
\hadithdefcmd{abudawud}{4150}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الأَسَدِيُّ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، بِهَذَا الْحَدِيثِ قَالَ وَكَانَ سِتْرًا مَوْشِيًّا ‏.‏\hadithno{4150}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2613)}\hadithtrans{The tradition mentioned above has also been transmitted through a different chain of narrators by Ibn Fudail on his father's authority. This version has:"The curtain was embellished}}
\hadithdefcmd{abudawud}{4151}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا عِمْرَانُ بْنُ حِطَّانَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَتْرُكُ فِي بَيْتِهِ شَيْئًا فِيهِ تَصْلِيبٌ إِلاَّ قَضَبَهُ ‏.‏\hadithno{4151}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5952)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) never left in his house anything containing the figure of a cross without destroying it}}
\hadithdefcmd{abudawud}{4152}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ نُجَىٍّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ صُورَةٌ وَلاَ كَلْبٌ وَلاَ جُنُبٌ ‏"‏ ‏.‏\hadithno{4152}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: The angels do not enter a house which contains a picture, a dog, or a man who is impure by sexual defilement}}
\hadithdefcmd{abudawud}{4153}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ سُهَيْلٍ، - يَعْنِي ابْنَ أَبِي صَالِحٍ - عَنْ سَعِيدِ بْنِ يَسَارٍ الأَنْصَارِيِّ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنْ أَبِي طَلْحَةَ الأَنْصَارِيِّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ تِمْثَالٌ ‏"‏ ‏.‏ وَقَالَ انْطَلِقْ بِنَا إِلَى أُمِّ الْمُؤْمِنِينَ عَائِشَةَ نَسْأَلُهَا عَنْ ذَلِكَ ‏.‏ فَانْطَلَقْنَا فَقُلْنَا يَا أُمَّ الْمُؤْمِنِينَ إِنَّ أَبَا طَلْحَةَ حَدَّثَنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِكَذَا وَكَذَا فَهَلْ سَمِعْتِ النَّبِيَّ صلى الله عليه وسلم يَذْكُرُ ذَلِكَ قَالَتْ لاَ وَلَكِنْ سَأُحَدِّثُكُمْ بِمَا رَأَيْتُهُ فَعَلَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ مَغَازِيهِ وَكُنْتُ أَتَحَيَّنُ قُفُولَهُ فَأَخَذْتُ نَمَطًا كَانَ لَنَا فَسَتَرْتُهُ عَلَى الْعَرَضِ فَلَمَّا جَاءَ اسْتَقْبَلْتُهُ فَقُلْتُ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ الْحَمْدُ لِلَّهِ الَّذِي أَعَزَّكَ وَأَكْرَمَكَ فَنَظَرَ إِلَى الْبَيْتِ فَرَأَى النَّمَطَ فَلَمْ يَرُدَّ عَلَىَّ شَيْئًا وَرَأَيْتُ الْكَرَاهِيَةَ فِي وَجْهِهِ فَأَتَى النَّمَطَ حَتَّى هَتَكَهُ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ لَمْ يَأْمُرْنَا فِيمَا رَزَقَنَا أَنْ نَكْسُوَ الْحِجَارَةَ وَاللَّبِنَ ‏"‏ ‏.‏ قَالَتْ فَقَطَعْتُهُ وَجَعَلْتُهُ وِسَادَتَيْنِ وَحَشَوْتُهُمَا لِيفًا فَلَمْ يُنْكِرْ ذَلِكَ عَلَىَّ ‏.‏\hadithno{4153}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2106)}\hadithtrans{Narrated Abu Talhat al-Ansari:I heard the Prophet (ﷺ) say: The angels do not enter a house which contains a dog or a picture. Zaid b. Khalid al-Juhani said to Sa'id b. Yasar al-Ansari, the transmitter of this tradition: Go with me to 'Aishah, Mother of Faithful, so that we ask about it. So we went and said to her: Mother of Faithful, Abu Talhah has transmitted to us a tradition so-and-so. Have you heard the Prophet (ﷺ) mentioning that ? She replied: No but I tell what I saw him doing. The Messenger of Allah (ﷺ) went on an expedition and I was waiting for his return. I got a carpet which I hung as a screen on a stick over the door. When he came I received him and said: Peace be upon you, Messenger of Allah, His mercy and His blessings. Praise to be Allah Who gave you dominance and respect. Then he looked at the house and saw the carpet; and he did not respond to me at all. I found (signs of) disapproval in his face. He then came to the carpet and tore it down. He then said: Allah has not commanded us to clothe stones and clay out of the sustenance He has given us. She said: I then cut it to pieces and made two pillows out of it and stuffed them with palm fibre, and he did not disapprove of it to me}}
\hadithdefcmd{abudawud}{4154}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، بِإِسْنَادِهِ مِثْلَهُ قَالَ فَقُلْتُ يَا أُمَّهْ إِنَّ هَذَا حَدَّثَنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ وَقَالَ فِيهِ سَعِيدُ بْنُ يَسَارٍ مَوْلَى بَنِي النَّجَّارِ ‏.‏\hadithno{4154}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Suhail through a different chain of narrators like the previous one. This version has:I said: Mother, he has told me that the Prophet (ﷺ) has said: He also said the words ; Sa'id b. yasir client of Banu al-Najjar}}
\hadithdefcmd{abudawud}{4155}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ، عَنْ أَبِي طَلْحَةَ، أَنَّهُ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ صُورَةٌ ‏"‏ ‏.‏ قَالَ بُسْرٌ ثُمَّ اشْتَكَى زَيْدٌ فَعُدْنَاهُ فَإِذَا عَلَى بَابِهِ سِتْرٌ فِيهِ صُورَةٌ فَقُلْتُ لِعُبَيْدِ اللَّهِ الْخَوْلاَنِيِّ رَبِيبِ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَلَمْ يُخْبِرْنَا زَيْدٌ عَنِ الصُّوَرِ يَوْمَ الأَوَّلِ فَقَالَ عُبَيْدُ اللَّهِ أَلَمْ تَسْمَعْهُ حِينَ قَالَ إِلاَّ رَقْمًا فِي ثَوْبٍ ‏.‏\hadithno{4155}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5958) Sahih Muslim (2106)}\hadithtrans{Narrated Abu Talhah:The Messenger of Allah (ﷺ) as saying: The angels do not enter the house which contains a picture. Busr (b. Sa'id), the transmitter of this tradition, said: Zaid (b. Khalid al-Juhani) then fell it and we paid him a sick visit. There was a curtain with a picture hanging at his door. I then said to 'Ubaid Allah al-Khawlani', the step-son of Maimunah, wife of the Prophet (ﷺ): Did Zaid not tell us about pictures on the first day ? 'Ubaid Allah said: Did you not hear him when he said: Except a figure on a garment}}
\hadithdefcmd{abudawud}{4156}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، أَنَّ إِسْمَاعِيلَ بْنَ عَبْدِ الْكَرِيمِ، حَدَّثَهُمْ قَالَ حَدَّثَنِي إِبْرَاهِيمُ، - يَعْنِي ابْنَ عَقِيلٍ - عَنْ أَبِيهِ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ عُمَرَ بْنَ الْخَطَّابِ - رضى الله عنه - زَمَنَ الْفَتْحِ وَهُوَ بِالْبَطْحَاءِ أَنْ يَأْتِيَ الْكَعْبَةَ فَيَمْحُوَ كُلَّ صُورَةٍ فِيهَا فَلَمْ يَدْخُلْهَا النَّبِيُّ صلى الله عليه وسلم حَتَّى مُحِيَتْ كُلُّ صُورَةٍ فِيهَا ‏.‏\hadithno{4156}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) ordered Umar ibn al-Khattab who was in al-Batha' at the time of the conquest (of Makkah) to visit the Ka'bah and obliterate all images in it. The Prophet (ﷺ) did not enter it until all the images were obliterated}}
\hadithdefcmd{abudawud}{4157}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ السَّبَّاقِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَتْنِي مَيْمُونَةُ، زَوْجُ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ كَانَ وَعَدَنِي أَنْ يَلْقَانِيَ اللَّيْلَةَ فَلَمْ يَلْقَنِي ‏"‏ ‏.‏ ثُمَّ وَقَعَ فِي نَفْسِهِ جَرْوُ كَلْبٍ تَحْتَ بِسَاطٍ لَنَا فَأَمَرَ بِهِ فَأُخْرِجَ ثُمَّ أَخَذَ بِيَدِهِ مَاءً فَنَضَحَ بِهِ مَكَانَهُ فَلَمَّا لَقِيَهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ قَالَ إِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ فَأَصْبَحَ النَّبِيُّ صلى الله عليه وسلم فَأَمَرَ بِقَتْلِ الْكِلاَبِ حَتَّى إِنَّهُ لَيَأْمُرُ بِقَتْلِ كَلْبِ الْحَائِطِ الصَّغِيرِ وَيَتْرُكُ كَلْبَ الْحَائِطِ الْكَبِيرِ ‏.‏\hadithno{4157}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2105)}\hadithtrans{Narrated Ibn 'Abbas:Maimunah, wife of the Prophet (ﷺ) reported him as saying: Gabriel (peace be upon him) promised to visit me last night, but he did not visit me. Then it occurred to him that there was a pup under his bed. So he ordered and it was turned out. He then got water in his hand and sprinkled it on its place. When Gabriel (ﷺ) met him, he said: We do not enter a house which contains a dog or a picture. When the morning came, the Prophet (ﷺ) ordered to kill dogs. He ordered to kill the dog which guarded a small orchard, and left the dog which guarded the big orchard}}
\hadithdefcmd{abudawud}{4158}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَانِي جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ لِي أَتَيْتُكَ الْبَارِحَةَ فَلَمْ يَمْنَعْنِي أَنْ أَكُونَ دَخَلْتُ إِلاَّ أَنَّهُ كَانَ عَلَى الْبَابِ تَمَاثِيلُ وَكَانَ فِي الْبَيْتِ قِرَامُ سِتْرٍ فِيهِ تَمَاثِيلُ وَكَانَ فِي الْبَيْتِ كَلْبٌ فَمُرْ بِرَأْسِ التِّمْثَالِ الَّذِي فِي الْبَيْتِ يُقْطَعُ فَيَصِيرُ كَهَيْئَةِ الشَّجَرَةِ وَمُرْ بِالسِّتْرِ فَلْيُقْطَعْ فَلْيُجْعَلْ مِنْهُ وِسَادَتَيْنِ مَنْبُوذَتَيْنِ تُوطَآنِ وَمُرْ بِالْكَلْبِ فَلْيُخْرَجْ ‏"‏ ‏.‏ فَفَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِذَا الْكَلْبُ لِحَسَنٍ أَوْ حُسَيْنٍ كَانَ تَحْتَ نَضَدٍ لَهُمْ فَأَمَرَ بِهِ فَأُخْرِجَ ‏.‏ قَالَ أَبُو دَاوُدَ وَالنَّضَدُ شَىْءٌ تُوضَعُ عَلَيْهِ الثِّيَابُ شِبْهُ السَّرِيرِ ‏.‏\hadithno{4158}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) said: Gabriel (ﷺ) came to me and said: I came to you last night and was prevented from entering simply because there were images at the door, for there was a decorated curtain with images on it in the house, and there was a dog in the house. So order the head of the image which is in the house to be cut off so that it resembles the form of a tree; order the curtain to be cut up and made into two cushions spread out on which people may tread; and order the dog to be turned out. The Messenger of Allah (ﷺ) then did so. The dog belonged to al-Hasan or al-Husayn and was under their couch. So he ordered it to be turned out. Abu Dawud said: Al-Nadd means a thing on which clothes are placed like a couch}}
